<?php
/*
 * Elementor Lovelove About Widget
 * Author & Copyright: wpoceans
*/

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Lovelove_About extends Widget_Base
{

	/**
	 * Retrieve the widget name.
	 */
	public function get_name()
	{
		return 'wpo-lovelove_about';
	}

	/**
	 * Retrieve the widget title.
	 */
	public function get_title()
	{
		return esc_html__('About', 'lovelove-core');
	}

	/**
	 * Retrieve the widget icon.
	 */
	public function get_icon()
	{
		return 'eicon-site-identity';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 */
	public function get_categories()
	{
		return ['wpoceans-category'];
	}

	/**
	 * Retrieve the list of scripts the Lovelove About widget depended on.
	 * Used to set scripts dependencies required to run the widget.
	 */
	public function get_script_depends()
	{
		return ['wpo-lovelove_about'];
	}

	/**
	 * Register Lovelove About widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 */
	protected function register_controls()
	{

		$this->start_controls_section(
			'section_about',
			[
				'label' => esc_html__('About Options', 'lovelove-core'),
			]
		);
		$repeater = new Repeater();
		$repeater->add_control(
			'about_style',
			[
				'label' => esc_html__('About Style', 'lovelove-core'),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'style-one' => esc_html__('Style One', 'lovelove-core'),
					'style-two' => esc_html__('Style Two', 'lovelove-core'),
				],
				'default' => 'style-one',
				'description' => esc_html__('Select your about style.', 'lovelove-core'),
			]
		);
		$repeater->add_control(
			'about_title',
			[
				'label' => esc_html__('Title Text', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__('About Us', 'lovelove-core'),
				'placeholder' => esc_html__('Sub Type title text here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'about_subtitle',
			[
				'label' => esc_html__('Sub Title Text', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__('Sub Title', 'lovelove-core'),
				'placeholder' => esc_html__('Sub Type title text here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'about_content',
			[
				'label' => esc_html__('Content', 'lovelove-core'),
				'default' => esc_html__('your content text', 'lovelove-core'),
				'placeholder' => esc_html__('Type your content here', 'lovelove-core'),
				'type' => Controls_Manager::TEXTAREA,
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'btn_text',
			[
				'label' => esc_html__('Button/Link Text', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__('Button Text', 'lovelove-core'),
				'placeholder' => esc_html__('Type btn text here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'button_link',
			[
				'label' => esc_html__('Button Link', 'lovelove-core'),
				'type' => Controls_Manager::URL,
				'placeholder' => 'https://your-link.com',
				'default' => [
					'url' => '',
				],
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'about_image',
			[
				'label' => esc_html__('About Image', 'lovelove-core'),
				'type' => Controls_Manager::MEDIA,
				'frontend_available' => true,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'description' => esc_html__('Set your image.', 'lovelove-core'),
			]
		);
		$repeater->add_control(
			'about_image2',
			[
				'label' => esc_html__('About Image 2', 'lovelove-core'),
				'type' => Controls_Manager::MEDIA,
				'frontend_available' => true,
				'condition' => [
					'about_style' => array('style-two'),
				],
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'description' => esc_html__('Set your signeture image.', 'lovelove-core'),
			]
		);
		$this->add_control(
			'about_groups',
			[
				'label' => esc_html__('About Items', 'lovelove-core'),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'about_title' => esc_html__('Item #1', 'lovelove-core'),
					],

				],
				'fields' =>  $repeater->get_controls(),
				'title_field' => '{{{ about_title }}}',
			]
		);
		$this->end_controls_section(); // end: Section

		// Title
		$this->start_controls_section(
			'section_title_style',
			[
				'label' => esc_html__('Title', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Typography', 'lovelove-core'),
				'name' => 'lovelove_title_typography',
				'selector' => '{{WRAPPER}} .lovelove-about .wpo-about-wrap .wpo-about-text h2',
			]
		);
		$this->add_control(
			'title_color',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lovelove-about .wpo-about-wrap .wpo-about-text h2' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'title_line_color',
			[
				'label' => esc_html__('Line Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-about-section .wpo-about-wrap .wpo-about-text h2:before, .wpo-about-section-s2 .wpo-about-wrap .wpo-about-text h2:before' => 'background-color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'title_padding',
			[
				'label' => esc_html__('Title Padding', 'lovelove-core'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em'],
				'selectors' => [
					'{{WRAPPER}} .lovelove-about .wpo-about-wrap .wpo-about-text h2' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section

		// Sub Title
		$this->start_controls_section(
			'section_subtitle_style',
			[
				'label' => esc_html__('Sub Title', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Typography', 'lovelove-core'),
				'name' => 'lovelove_subtitle_typography',
				'selector' => '{{WRAPPER}} .lovelove-about .wpo-about-wrap .wpo-about-text h4',
			]
		);
		$this->add_control(
			'subtitle_color',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lovelove-about .wpo-about-wrap .wpo-about-text h4' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'subtitle_padding',
			[
				'label' => esc_html__('Title Padding', 'lovelove-core'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em'],
				'selectors' => [
					'{{WRAPPER}} .lovelove-about .wpo-about-wrap .wpo-about-text h4' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section

		// Content
		$this->start_controls_section(
			'section_content_style',
			[
				'label' => esc_html__('Content', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Typography', 'lovelove-core'),
				'name' => 'section_content_typography',
				'selector' => '{{WRAPPER}} .lovelove-about .wpo-about-wrap .wpo-about-text p',
			]
		);
		$this->add_control(
			'content_color',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lovelove-about .wpo-about-wrap .wpo-about-text p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'content_padding',
			[
				'label' => esc_html__('Content Padding', 'lovelove-core'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em'],
				'selectors' => [
					'{{WRAPPER}} .lovelove-about .wpo-about-wrap .wpo-about-text p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section

		// Button
		$this->start_controls_section(
			'section_bout_btn_style',
			[
				'label' => esc_html__('Button', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'button_color',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lovelove-about .wpo-about-wrap .wpo-about-text .theme-btn' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'button_br_color',
			[
				'label' => esc_html__('Border Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lovelove-about .wpo-about-wrap .wpo-about-text .theme-btn' => 'border-color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'button_bg_color',
			[
				'label' => esc_html__('Background Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lovelove-about .wpo-about-wrap .wpo-about-text .theme-btn' => 'background-color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'button_hover_color',
			[
				'label' => esc_html__('Hover Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lovelove-about .wpo-about-wrap .wpo-about-text .theme-btn:hover' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_hover_bg_color',
			[
				'label' => esc_html__('Hover BG Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lovelove-about .wpo-about-wrap .wpo-about-text .theme-btn:hover' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section(); // end: Section


	}

	/**
	 * Render About widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 */
	protected function render()
	{
		$settings = $this->get_settings_for_display();
		$about_groups = !empty($settings['about_groups']) ? $settings['about_groups'] : [];
		$about_style = !empty($settings['about_style']) ? $settings['about_style'] : '';

		if ($about_style ==  'style-one') {
			$about_wrap = 'wpo-about-section';
		} else {
			$about_wrap = 'wpo-about-section-s2';
		}

		// Turn output buffer on
		ob_start(); ?>
		<div class="lovelove-about <?php echo esc_attr($about_wrap) ?>">
			<div class="container">
				<?php
				$id = 0;
				if (is_array($about_groups) && !empty($about_groups)) {
					foreach ($about_groups as $each_item) {
						$about_style = !empty($each_item['about_style']) ? $each_item['about_style'] : '';

						$id++;

						if ($about_style == 'style-one' &&  $id % 2 === 0) {
							$col_order_one = 'order-lg-1 order-2';
							$col_order_two = 'order-lg-2 order-1';
						} else {
							$col_order_one = '';
							$col_order_two = '';
						}


						$bg_image = !empty($each_item['about_image']['id']) ? $each_item['about_image']['id'] : '';
						$bg_image2 = !empty($each_item['about_image2']['id']) ? $each_item['about_image2']['id'] : '';

						$about_url = wp_get_attachment_url($bg_image);
						$about_alt = get_post_meta($bg_image, '_wp_attachment_image_alt', true);
						$about2_url = wp_get_attachment_url($bg_image2);
						$about2_alt = get_post_meta($bg_image2, '_wp_attachment_image_alt', true);

						$about_title = !empty($each_item['about_title']) ? $each_item['about_title'] : '';
						$about_subtitle = !empty($each_item['about_subtitle']) ? $each_item['about_subtitle'] : '';
						$about_content = !empty($each_item['about_content']) ? $each_item['about_content'] : '';

						$button_text = !empty($each_item['btn_text']) ? $each_item['btn_text'] : '';
						$button_link = !empty($each_item['button_link']['url']) ? $each_item['button_link']['url'] : '';
						$button_link_external = !empty($each_item['button_link']['is_external']) ? 'target="_blank"' : '';
						$button_link_nofollow = !empty($each_item['button_link']['nofollow']) ? 'rel="nofollow"' : '';
						$button_link_attr = !empty($button_link) ?  $button_link_external . ' ' . $button_link_nofollow : '';

						$button_one = $button_link ? '<a href="' . esc_url($button_link) . '" ' . $button_link_attr . ' class="theme-btn" >' . $button_text . '</a>' : '';

				?>
						<div class="wpo-about-wrap">
							<div class="row">
								<div class="col-lg-6 col-md-12 col-12 <?php echo esc_attr($col_order_two); ?>">
									<div class="wpo-about-item">
										<?php if ($about_url) {
											echo '<div class="wpo-about-img"><img src="' . esc_url($about_url) . '" alt="' . esc_attr($about_alt) . '"></div>';
										} ?>
										<?php if ($about2_url) {
											echo '<div class="wpo-about-img-inner"><img src="' . esc_url($about2_url) . '" alt="' . esc_attr($about2_alt) . '"></div>';
										} ?>
									</div>
								</div>
								<div class="col-lg-6 col-md-12 col-12 <?php echo esc_attr($col_order_one); ?>">
									<div class="wpo-about-text">
										<?php
										if ($about_title) {
											echo '<h2>' . esc_html($about_title) . '</h2>';
										}
										if ($about_subtitle) {
											echo '<h4>' . esc_html($about_subtitle) . '</h4>';
										}
										if ($about_content) {
											echo '<p>' . esc_html($about_content) . '</p>';
										}
										echo $button_one;
										?>
									</div>
								</div>
							</div>
						</div>
				<?php }
				} ?>
			</div>
		</div>
<?php
		echo ob_get_clean();
	}
	/**
	 * Render About widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 */

	//protected function _content_template(){}

}
Plugin::instance()->widgets_manager->register(new Lovelove_About());
