<?php
/*
 * Elementor Lovelove Blog Widget
 * Author & Copyright: wpoceans
*/

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Lovelove_Blog extends Widget_Base
{

	/**
	 * Retrieve the widget name.
	 */
	public function get_name()
	{
		return 'wpo-lovelove_blog';
	}

	/**
	 * Retrieve the widget title.
	 */
	public function get_title()
	{
		return esc_html__('Blog', 'lovelove-core');
	}

	/**
	 * Retrieve the widget icon.
	 */
	public function get_icon()
	{
		return 'eicon-posts-grid';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 */
	public function get_categories()
	{
		return ['wpoceans-category'];
	}

	/**
	 * Retrieve the list of scripts the Lovelove Blog widget depended on.
	 * Used to set scripts dependencies required to run the widget.
	 */
	public function get_script_depends()
	{
		return ['wpo-lovelove_blog'];
	}

	/**
	 * Register Lovelove Blog widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 */
	protected function register_controls()
	{

		$posts = get_posts('post_type="post"&numberposts=-1');
		$PostID = array();
		if ($posts) {
			foreach ($posts as $post) {
				$PostID[$post->ID] = $post->ID;
			}
		} else {
			$PostID[__('No ID\'s found', 'lovelove')] = 0;
		}


		$this->start_controls_section(
			'section_blog_metas',
			[
				'label' => esc_html__('Meta\'s Options', 'lovelove-core'),
			]
		);
		$this->add_control(
			'blog_image',
			[
				'label' => esc_html__('Image', 'lovelove-core'),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__('Show', 'lovelove-core'),
				'label_off' => esc_html__('Hide', 'lovelove-core'),
				'return_value' => 'true',
				'default' => 'true',
			]
		);
		$this->add_control(
			'blog_date',
			[
				'label' => esc_html__('Date', 'lovelove-core'),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__('Show', 'lovelove-core'),
				'label_off' => esc_html__('Hide', 'lovelove-core'),
				'return_value' => 'true',
				'default' => 'true',
			]
		);
		$this->end_controls_section(); // end: Section


		$this->start_controls_section(
			'section_blog_listing',
			[
				'label' => esc_html__('Listing Options', 'lovelove-core'),
			]
		);
		$this->add_control(
			'blog_limit',
			[
				'label' => esc_html__('Blog Limit', 'lovelove-core'),
				'type' => Controls_Manager::NUMBER,
				'min' => 1,
				'max' => 100,
				'step' => 1,
				'default' => 3,
				'description' => esc_html__('Enter the number of items to show.', 'lovelove-core'),
			]
		);
		$this->add_control(
			'blog_order',
			[
				'label' => __('Order', 'lovelove-core'),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'ASC' => esc_html__('Asending', 'lovelove-core'),
					'DESC' => esc_html__('Desending', 'lovelove-core'),
				],
				'default' => 'DESC',
			]
		);
		$this->add_control(
			'blog_orderby',
			[
				'label' => __('Order By', 'lovelove-core'),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'none' => esc_html__('None', 'lovelove-core'),
					'ID' => esc_html__('ID', 'lovelove-core'),
					'author' => esc_html__('Author', 'lovelove-core'),
					'title' => esc_html__('Title', 'lovelove-core'),
					'date' => esc_html__('Date', 'lovelove-core'),
				],
				'default' => 'date',
			]
		);
		$this->add_control(
			'blog_show_category',
			[
				'label' => __('Certain Categories?', 'lovelove-core'),
				'type' => Controls_Manager::SELECT2,
				'default' => [],
				'options' => Controls_Helper_Output::get_terms_names('category'),
				'multiple' => true,
			]
		);
		$this->add_control(
			'blog_show_id',
			[
				'label' => __('Certain ID\'s?', 'lovelove-core'),
				'type' => Controls_Manager::SELECT2,
				'default' => [],
				'options' => $PostID,
				'multiple' => true,
			]
		);
		$this->add_control(
			'blog_pagination',
			[
				'label' => esc_html__('Pagination', 'lovelove-core'),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__('Show', 'lovelove-core'),
				'label_off' => esc_html__('Hide', 'lovelove-core'),
				'return_value' => 'true',
				'default' => 'true',
			]
		);

		$this->end_controls_section(); // end: Section


		// Title
		$this->start_controls_section(
			'section_title_style',
			[
				'label' => esc_html__('Title', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Typography', 'lovelove-core'),
				'name' => 'lovelove_title_typography',
				'selector' => '{{WRAPPER}} .wpo-blog-section .wpo-blog-items .wpo-blog-grids .grid .wpo-blog-item .wpo-blog-content h2',
			]
		);
		$this->add_control(
			'title_color',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-blog-section .wpo-blog-items .wpo-blog-grids .grid .wpo-blog-item .wpo-blog-content h2 a' => 'color: {{VALUE}};'
				],
			]
		);
		$this->add_control(
			'title_padding',
			[
				'label' => __('Title Padding', 'lovelove-core'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em'],
				'selectors' => [
					'{{WRAPPER}} .wpo-blog-section .wpo-blog-items .wpo-blog-grids .grid .wpo-blog-item .wpo-blog-content h2' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section


		// Date
		$this->start_controls_section(
			'blog_section_date_style',
			[
				'label' => esc_html__('Date', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Typography', 'lovelove-core'),
				'name' => 'blog_section_date_typography',
				'selector' => '{{WRAPPER}} .wpo-blog-section .wpo-blog-items .wpo-blog-grids .grid .wpo-blog-item .wpo-blog-content ul li',
			]
		);
		$this->add_control(
			'blog_date_color',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-blog-section .wpo-blog-items .wpo-blog-grids .grid .wpo-blog-item .wpo-blog-content ul li' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'blog_date_stock_color',
			[
				'label' => esc_html__('Stock Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-blog-section .wpo-blog-items .wpo-blog-grids .grid:nth-child(1) .wpo-blog-item .wpo-blog-content ul li:first-child' => '-webkit-text-stroke-color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section


	}

	/**
	 * Render Blog widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 */
	protected function render()
	{
		$settings = $this->get_settings_for_display();

		$blog_limit = !empty($settings['blog_limit']) ? $settings['blog_limit'] : '';
		$blog_image  = (isset($settings['blog_image']) && ('true' == $settings['blog_image'])) ? true : false;
		$blog_date  = (isset($settings['blog_date']) && ('true' == $settings['blog_date'])) ? true : false;

		$blog_order = !empty($settings['blog_order']) ? $settings['blog_order'] : '';
		$blog_orderby = !empty($settings['blog_orderby']) ? $settings['blog_orderby'] : '';
		$blog_show_category = !empty($settings['blog_show_category']) ? $settings['blog_show_category'] : [];
		$blog_show_id = !empty($settings['blog_show_id']) ? $settings['blog_show_id'] : [];
		$blog_pagination  = (isset($settings['blog_pagination']) && ('true' == $settings['blog_pagination'])) ? true : false;

		// Turn output buffer on
		ob_start();


		// Pagination
		global $paged;
		if (get_query_var('paged'))
			$my_page = get_query_var('paged');
		else {
			if (get_query_var('page'))
				$my_page = get_query_var('page');
			else
				$my_page = 1;
			set_query_var('paged', $my_page);
			$paged = $my_page;
		}

		if ($blog_show_id) {
			$blog_show_id = json_encode($blog_show_id);
			$blog_show_id = str_replace(array('[', ']'), '', $blog_show_id);
			$blog_show_id = str_replace(array('"', '"'), '', $blog_show_id);
			$blog_show_id = explode(',', $blog_show_id);
		} else {
			$blog_show_id = '';
		}

		$args = array(
			// other query params here,
			'paged' => $my_page,
			'post_type' => 'post',
			'posts_per_page' => (int)$blog_limit,
			'category_name' => implode(',', $blog_show_category),
			'orderby' => $blog_orderby,
			'order' => $blog_order,
			'post__in' => $blog_show_id,
		);

		$lovelove_post = new \WP_Query($args); ?>

		<div class="wpo-blog-section">
			<div class="container">
				<div class="wpo-blog-items">
					<div class="row">
						<div class="col-lg-12">
							<div class="wpo-blog-grids clearfix">
								<?php
								$id = 0;
								if ($lovelove_post->have_posts()) : while ($lovelove_post->have_posts()) : $lovelove_post->the_post();
										$id++;
										$lovelove_large_image =  wp_get_attachment_image_src(get_post_thumbnail_id(get_the_ID()), 'lovelove-grid-post-left', false, '');
										$lovelove_alt = get_post_meta($lovelove_large_image, '_wp_attachment_image_alt', true);

										$lovelove_large_image2 =  wp_get_attachment_image_src(get_post_thumbnail_id(get_the_ID()), 'lovelove-grid-post-right', false, '');
										$lovelove_alt2 = get_post_meta($lovelove_large_image2, '_wp_attachment_image_alt', true);

								?>
										<div class="grid">
											<div class="wpo-blog-item">

												<?php if ($id == 1) { ?>
													<?php if ($blog_image) { ?>
														<div class="wpo-blog-img">
															<img src="<?php echo esc_url($lovelove_large_image[0]); ?>" alt="<?php echo esc_attr($lovelove_alt); ?>">
														</div>
													<?php } ?>
													<div class="wpo-blog-content">
														<?php if ($blog_date) { ?>
															<ul>
																<li><?php echo esc_html(get_the_date('d'));  ?></li>
																<li><?php echo esc_html(get_the_date('F'));  ?></li>
															</ul>
														<?php }	?>
														<h2>
															<a href="<?php echo esc_url(get_permalink()); ?>">
																<?php echo esc_html(get_the_title()); ?>
															</a>
														</h2>
													</div>
												<?php } else { ?>
													<?php if ($blog_image) { ?>
														<div class="wpo-blog-img">
															<img src="<?php echo esc_url($lovelove_large_image2[0]); ?>" alt="<?php echo esc_attr($lovelove_alt2); ?>">
														</div>
													<?php } ?>
													<div class="wpo-blog-content">
														<h2>
															<a href="<?php echo esc_url(get_permalink()); ?>">
																<?php echo esc_html(get_the_title()); ?>
															</a>
														</h2>
														<?php if ($blog_date) { ?>
															<ul>
																<li><?php echo esc_html(get_the_date('d M Y'));  ?></li>
															</ul>
														<?php }	?>
													</div>
												<?php } ?>

											</div>
										</div>
									<?php
									endwhile;
								endif;
								wp_reset_postdata();
								if ($blog_pagination) { ?>
									<div class="page-pagination-wrap">
										<?php echo '<div class="paginations">';
										$big = 999999999;
										echo paginate_links(array(
											'base'      => str_replace($big, '%#%', get_pagenum_link($big)),
											'format'    => '?paged=%#%',
											'total'     => $lovelove_post->max_num_pages,
											'show_all'  => false,
											'current'   => max(1, $my_page),
											'prev_text'    => '<div class="fi flaticon-back"></div>',
											'next_text'    => '<div class="fi flaticon-next"></div>',
											'mid_size'  => 1,
											'type'      => 'list'
										));
										echo '</div>'; ?>
									</div>
								<?php } ?>
							</div>
						</div>
					</div>
				</div>
			</div> <!-- end container -->
		</div>
<?php
		// Return outbut buffer
		echo ob_get_clean();
	}
	/**
	 * Render Blog widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 */

	//protected function _content_template(){}

}
Plugin::instance()->widgets_manager->register(new Lovelove_Blog());
