<?php
/*
 * Elementor Lovelove Contact Form 7 Widget
 * Author & Copyright: wpoceans
*/

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Lovelove_Contact_Form extends Widget_Base
{

	/**
	 * Retrieve the widget name.
	 */
	public function get_name()
	{
		return 'wpo-lovelove_contact_form';
	}

	/**
	 * Retrieve the widget title.
	 */
	public function get_title()
	{
		return esc_html__('Contact Form', 'lovelove-core');
	}

	/**
	 * Retrieve the widget icon.
	 */
	public function get_icon()
	{
		return 'eicon-form-horizontal';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 */
	public function get_categories()
	{
		return ['wpoceans-category'];
	}

	/**
	 * Retrieve the list of scripts the Lovelove Contact Form widget depended on.
	 * Used to set scripts dependencies required to run the widget.
	 */
	/*
	public function get_script_depends() {
		return ['wpo-lovelove_contact_form'];
	}
	 */

	/**
	 * Register Lovelove Contact Form widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 */
	protected function register_controls()
	{

		$this->start_controls_section(
			'section_contact_form',
			[
				'label' => esc_html__('Form Options', 'lovelove-core'),
			]
		);
		$this->add_control(
			'form_style',
			[
				'label' => esc_html__('Contact Style', 'lovelove-core'),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'style-one' => esc_html__('Style One', 'lovelove-core'),
					'style-two' => esc_html__('Style Two', 'lovelove-core'),
					'style-three' => esc_html__('Style Three', 'lovelove-core'),
					'style-four' => esc_html__('Style Four', 'lovelove-core'),
				],
				'default' => 'style-one',
				'description' => esc_html__('Select your contact style.', 'finco-core'),
			]
		);
		$this->add_control(
			'section_title',
			[
				'label' => esc_html__('Title Text', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__('Title Text', 'lovelove-core'),
				'placeholder' => esc_html__('Type title text here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$this->add_control(
			'section_subtitle',
			[
				'label' => esc_html__('Sub Title Text', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'condition' => [
					'form_style' => array('style-one', 'style-two'),
				],
				'default' => esc_html__('Sub Title Text', 'lovelove-core'),
				'placeholder' => esc_html__('Type subtitle text here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$this->add_control(
			'section_content',
			[
				'label' => esc_html__('Content', 'lovelove-core'),
				'default' => esc_html__('your content text', 'lovelove-core'),
				'placeholder' => esc_html__('Type your content here', 'lovelove-core'),
				'type' => Controls_Manager::TEXTAREA,
				'condition' => [
					'form_style' => array('style-two'),
				],
				'label_block' => true,
			]
		);
		$this->add_control(
			'btn_text',
			[
				'label' => esc_html__('Button/Link Text', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'condition' => [
					'form_style' => array('style-two'),
				],
				'default' => esc_html__('Button Text', 'lovelove-core'),
				'placeholder' => esc_html__('Type btn text here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$this->add_control(
			'btn_link',
			[
				'label' => esc_html__('Button Link', 'lovelove-core'),
				'type' => Controls_Manager::URL,
				'condition' => [
					'form_style' => array('style-two'),
				],
				'placeholder' => 'https://your-link.com',
				'default' => [
					'url' => '',
				],
				'label_block' => true,
			]
		);
		$this->add_control(
			'shape_image',
			[
				'label' => esc_html__('Shape Image', 'lovelove-core'),
				'type' => Controls_Manager::MEDIA,
				'condition' => [
					'form_style' => array('style-one', 'style-three'),
				],
				'frontend_available' => true,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'description' => esc_html__('Set your image.', 'lovelove-core'),
			]
		);
		$this->add_control(
			'shape_image2',
			[
				'label' => esc_html__('Shape Image 2', 'lovelove-core'),
				'type' => Controls_Manager::MEDIA,
				'condition' => [
					'form_style' => array('style-one', 'style-three'),
				],
				'frontend_available' => true,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'description' => esc_html__('Set your image.', 'lovelove-core'),
			]
		);
		$this->add_control(
			'bg_image',
			[
				'label' => esc_html__('BG Image', 'lovelove-core'),
				'type' => Controls_Manager::MEDIA,
				'condition' => [
					'form_style' => array('style-one', 'style-two', 'style-four'),
				],
				'frontend_available' => true,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'description' => esc_html__('Set your image.', 'lovelove-core'),
			]
		);
		$this->add_control(
			'bg_image2',
			[
				'label' => esc_html__('BG Image 2', 'lovelove-core'),
				'type' => Controls_Manager::MEDIA,
				'condition' => [
					'form_style' => array('style-one'),
				],
				'frontend_available' => true,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'description' => esc_html__('Set your image.', 'lovelove-core'),
			]
		);
		$this->add_control(
			'form_id',
			[
				'label' => esc_html__('Select contact form', 'lovelove-core'),
				'type' => Controls_Manager::SELECT,
				'options' => Controls_Helper_Output::get_posts('wpcf7_contact_form'),
			]
		);
		$this->end_controls_section(); // end: Section

		// Subtitle
		$this->start_controls_section(
			'section_subtitle_style',
			[
				'label' => esc_html__('Sub Title', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Typography', 'lovelove-core'),
				'name' => 'section_subtitle_typography',
				'selector' => '{{WRAPPER}} .lovelove-rsvp-form .wpo-section-title h4',
			]
		);
		$this->add_control(
			'subtitle_color',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lovelove-rsvp-form .wpo-section-title h4' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section

		// Title
		$this->start_controls_section(
			'section_title_style',
			[
				'label' => esc_html__('Title', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'lovelove_title_typography',
				'selector' => '{{WRAPPER}} .lovelove-rsvp-form .wpo-section-title h2, .wpo-contact-section-s3 .contact-img .rsvp-info .info-left h2',
			]
		);
		$this->add_control(
			'title_color',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lovelove-rsvp-form .wpo-section-title h2, .wpo-contact-section-s3 .contact-img .rsvp-info .info-left h2' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'title_line_color',
			[
				'label' => esc_html__('Line Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lovelove-rsvp-form .wpo-section-title h2::before, .lovelove-rsvp-form .wpo-section-title h2::after' => 'background-color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'title_padding',
			[
				'label' => esc_html__('Title Padding', 'lovelove-core'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors' => [
					'{{WRAPPER}} .lovelove-rsvp-form .wpo-section-title h2' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section

		// Content
		$this->start_controls_section(
			'section_content_style',
			[
				'label' => esc_html__('Content', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'form_style' => array('style-two'),
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Typography', 'lovelove-core'),
				'name' => 'section_content_typography',
				'selector' => '{{WRAPPER}} .wpo-contact-section-s3 .contact-img .rsvp-info .info-left p',
			]
		);
		$this->add_control(
			'content_color',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-contact-section-s3 .contact-img .rsvp-info .info-left p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'content_padding',
			[
				'label' => esc_html__('Content Padding', 'lovelove-core'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em'],
				'selectors' => [
					'{{WRAPPER}} .wpo-contact-section-s3 .contact-img .rsvp-info .info-left p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section

		// Content button
		$this->start_controls_section(
			'section_content_btn_style',
			[
				'label' => esc_html__('Content Button', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'form_style' => array('style-two'),
				],
			]
		);
		$this->add_control(
			'content_btn_color',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-contact-section-s3 .contact-img .rsvp-info .btn .theme-btn' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'content_btn_br_color',
			[
				'label' => esc_html__('Border Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-contact-section-s3 .contact-img .rsvp-info .btn .theme-btn' => 'border-color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'content_btn_hover_color',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-contact-section-s3 .contact-img .rsvp-info .btn .theme-btn:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'content_btn_hover_bg_color',
			[
				'label' => esc_html__('BG Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-contact-section-s3 .contact-img .rsvp-info .btn .theme-btn:hover' => 'background-color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'content_btn_padding',
			[
				'label' => esc_html__('Content Padding', 'lovelove-core'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em'],
				'selectors' => [
					'{{WRAPPER}} .wpo-contact-section-s3 .contact-img .rsvp-info .btn .theme-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section

		// Form Box
		$this->start_controls_section(
			'section_form_box_style',
			[
				'label' => esc_html__('Form Box', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'form_box_border',
			[
				'label' => esc_html__('Box Border Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area' => 'background-color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section

		$this->start_controls_section(
			'section_form_style',
			[
				'label' => esc_html__('Form', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'form_typography',
				'selector' => '{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area input[type="text"], 
				{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area input[type="email"], 
				{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area input[type="date"], 
				{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area input[type="time"], 
				{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area input[type="number"], 
				{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area textarea, 
				{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area select, 
				{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area .form-control, 
				{{WRAPPER}} .track-contact .track-trace select, 
				{{WRAPPER}} .track-contact .track-trace input',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'form_border',
				'label' => esc_html__('Border', 'lovelove-core'),
				'selector' => '{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area input[type="text"], 
				{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area input[type="email"], 
				{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-areainput[type="date"], 
				{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area input[type="time"], 
				{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area input[type="number"], 
				{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area textarea, 
				{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area select, 
				{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area .form-control, 
				{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area .nice-select,
				{{WRAPPER}} .track-contact .track-trace select, 
				{{WRAPPER}} .track-contact .track-trace input',

			]
		);
		$this->add_control(
			'placeholder_text_color',
			[
				'label' => __('Placeholder Text Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area input:not([type="submit"])::-webkit-input-placeholder' => 'color: {{VALUE}} !important;',
					'{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area input:not([type="submit"])::-moz-placeholder' => 'color: {{VALUE}} !important;',
					'{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area input:not([type="submit"])::-ms-input-placeholder' => 'color: {{VALUE}} !important;',
					'{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area input:not([type="submit"])::-o-placeholder' => 'color: {{VALUE}} !important;',
					'{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area textarea::-webkit-input-placeholder' => 'color: {{VALUE}} !important;',
					'{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area textarea::-moz-placeholder' => 'color: {{VALUE}} !important;',
					'{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area textarea::-ms-input-placeholder' => 'color: {{VALUE}} !important;',
					'{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area textarea::-o-placeholder' => 'color: {{VALUE}} !important;',
					'{{WRAPPER}} .track-contact .track-trace input::-webkit-input-placeholder' => 'color: {{VALUE}} !important;',
					'{{WRAPPER}} .track-contact .track-trace select::-webkit-input-placeholder' => 'color: {{VALUE}} !important;',
				],
			]
		);
		$this->add_control(
			'label_color',
			[
				'label' => __('Label Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area label' => 'color: {{VALUE}} !important;',
				],
			]
		);
		$this->add_control(
			'text_color',
			[
				'label' => __('Text Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area input[type="text"], 
					{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area input[type="email"], 
					{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area input[type="date"], 
					{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area input[type="time"], 
					{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area input[type="number"], 
					{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area textarea, 
					{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area select, 
					{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area .form-control, 
					{{WRAPPER}} .track-contact .track-trace input, 
					{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area .nice-select' => 'color: {{VALUE}} !important;',
				],
			]
		);
		$this->end_controls_section(); // end: Section

		$this->start_controls_section(
			'section_button_style',
			[
				'label' => esc_html__('Button', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'button_typography',
				'selector' => '{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area .wpcf7-form-control.wpcf7-submit',
			]
		);
		$this->add_responsive_control(
			'btn_width',
			[
				'label' => esc_html__('Width', 'lovelove-core'),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 1,
					],
				],
				'size_units' => ['px', '%'],
				'selectors' => [
					'{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area .wpcf7-form-control.wpcf7-submit' => 'min-width: {{SIZE}}{{UNIT}};',
				],
			]
		);
		$this->add_control(
			'btn_margin',
			[
				'label' => __('Margin', 'lovelove-core'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em'],
				'selectors' => [
					'{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area .wpcf7-form-control.wpcf7-submit' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_control(
			'button_border_radius',
			[
				'label' => __('Border Radius', 'lovelove-core'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors' => [
					'{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area .wpcf7-form-control.wpcf7-submit' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->start_controls_tabs('button_style');
		$this->start_controls_tab(
			'button_normal',
			[
				'label' => esc_html__('Normal', 'lovelove-core'),
			]
		);
		$this->add_control(
			'button_color',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area .wpcf7-form-control.wpcf7-submit' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'button_bg_color',
			[
				'label' => esc_html__('Background Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area .wpcf7-form-control.wpcf7-submit' => 'background-color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'button_border',
				'label' => esc_html__('Border', 'lovelove-core'),
				'selector' => '{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area .wpcf7-form-control.wpcf7-submit',
			]
		);
		$this->end_controls_tab();  // end:Normal tab

		$this->start_controls_tab(
			'button_hover',
			[
				'label' => esc_html__('Hover', 'lovelove-core'),
			]
		);
		$this->add_control(
			'button_hover_color',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area .wpcf7-form-control.wpcf7-submit:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'button_bg_hover_color',
			[
				'label' => esc_html__('Background Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area .wpcf7-form-control.wpcf7-submit:hover' => 'background-color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'button_hover_border',
				'label' => esc_html__('Border', 'lovelove-core'),
				'selector' => '{{WRAPPER}} .lovelove-rsvp-form  .wpo-contact-form-area .wpcf7-form-control.wpcf7-submit:hover',
			]
		);
		$this->end_controls_tab();  // end:Hover tab
		$this->end_controls_tabs(); // end tabs

		$this->end_controls_section(); // end: Section

	}

	/**
	 * Render Contact Form widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 */
	protected function render()
	{
		$settings = $this->get_settings_for_display();
		$form_style = !empty($settings['form_style']) ? $settings['form_style'] : '';

		$form_id = !empty($settings['form_id']) ? $settings['form_id'] : '';
		$section_subtitle = !empty($settings['section_subtitle']) ? $settings['section_subtitle'] : '';
		$section_title = !empty($settings['section_title']) ? $settings['section_title'] : '';
		$section_content = !empty($settings['section_content']) ? $settings['section_content'] : '';

		$bg_shape = !empty($settings['shape_image']['id']) ? $settings['shape_image']['id'] : '';
		$bg_shape2 = !empty($settings['shape_image2']['id']) ? $settings['shape_image2']['id'] : '';

		$image_bg = !empty($settings['bg_image']['id']) ? $settings['bg_image']['id'] : '';
		$image_bg2 = !empty($settings['bg_image2']['id']) ? $settings['bg_image2']['id'] : '';

		// Image
		$shape_url = wp_get_attachment_url($bg_shape);
		$shape_alt = get_post_meta($bg_shape, '_wp_attachment_image_alt', true);

		// Image
		$shape2_url = wp_get_attachment_url($bg_shape2);
		$shape2_alt = get_post_meta($bg_shape2, '_wp_attachment_image_alt', true);
		// Image

		$image_url = wp_get_attachment_url($image_bg);
		$image_alt = get_post_meta($image_bg, '_wp_attachment_image_alt', true);

		$image2_url = wp_get_attachment_url($image_bg2);
		$image2_alt = get_post_meta($image_bg2, '_wp_attachment_image_alt', true);

		$btn_text = !empty($settings['btn_text']) ? $settings['btn_text'] : '';
		$btn_paragraph = !empty($settings['btn_paragraph']) ? $settings['btn_paragraph'] : '';
		$btn_icon = !empty($settings['btn_icon']) ? $settings['btn_icon'] : '';

		$btn_link = !empty($settings['btn_link']['url']) ? $settings['btn_link']['url'] : '';
		$btn_external = !empty($settings['btn_link']['is_external']) ? 'target="_blank"' : '';
		$btn_nofollow = !empty($settings['btn_link']['nofollow']) ? 'rel="nofollow"' : '';
		$btn_link_attr = !empty($btn_link) ?  $btn_external . ' ' . $btn_nofollow : '';

		$button_one = $btn_link ? '<a href="' . esc_url($btn_link) . '" ' . $btn_link_attr . ' class="theme-btn" >' . $btn_text . '</a>' : '';

		// Turn output buffer on
		ob_start();
		if ($form_style == 'style-one') { ?>
			<div class="lovelove-rsvp-form wpo-contact-section">
				<div class="container-fluid">
					<div class="row align-items-center">
						<div class="col col-xl-4 col-lg-3 col-md-3 col-12">
							<div class="contact-img">
								<?php if ($image_url) {
									echo '<img src="' . esc_url($image_url) . '" alt="' . esc_attr($image_alt) . '">';
								} ?>
							</div>
						</div>
						<div class="col col-xl-4 col-lg-6 col-md-6 col-12">
							<div class="wpo-contact-section-wrapper">
								<div class="wpo-contact-form-area">
									<div class="wpo-section-title">
										<?php
										if ($section_subtitle) {
											echo '<h4>' . esc_html($section_subtitle) . '</h4>';
										}
										if ($section_title) {
											echo '<h2>' . esc_html($section_title) . '</h2>';
										}
										?>
									</div>
									<div class="lovelove-form">
										<?php echo do_shortcode('[contact-form-7 id="' . $form_id . '"]'); ?>
									</div>
								</div>
								<div class="vector-1">
									<?php if ($shape_url) {
										echo '<img src="' . esc_url($shape_url) . '" alt="' . esc_attr($shape_alt) . '">';
									} ?>
								</div>
								<div class="vector-2">
									<?php if ($shape2_url) {
										echo '<img src="' . esc_url($shape2_url) . '" alt="' . esc_attr($shape2_alt) . '">';
									} ?>
								</div>
							</div>
						</div>
						<div class="col col-xl-4 col-lg-3 col-md-3 col-12">
							<div class="contact-img">
								<?php if ($image2_url) {
									echo '<img src="' . esc_url($image2_url) . '" alt="' . esc_attr($image2_alt) . '">';
								} ?>
							</div>
						</div>
					</div>
				</div>
			</div>
		<?php } elseif ($form_style == 'style-two') { ?>
			<div class="lovelove-rsvp-form wpo-contact-section-s3">
				<div class="container">
					<div class="row align-items-center">
						<div class="col col-xl-4 col-lg-6 col-md-12 col-12">
							<div class="wpo-contact-section-wrapper">
								<div class="wpo-contact-form-area">
									<div class="wpo-section-title">
										<?php
										if ($section_title) {
											echo '<h4>' . esc_html($section_title) . '</h4>';
										}
										?>
									</div>
									<div class="lovelove-from">
										<?php echo do_shortcode('[contact-form-7 id="' . $form_id . '"]'); ?>
									</div>
								</div>
							</div>
						</div>
						<div class="col col-xl-8 col-lg-6 col-md-12 col-12">
							<div class="contact-img">
								<?php if ($image_url) {
									echo '<img src="' . esc_url($image_url) . '" alt="' . esc_attr($image_alt) . '">';
								} ?>
								<div class="rsvp-info">
									<div class="info-left">
										<?php
										if ($section_subtitle) {
											echo '<h2>' . esc_html($section_subtitle) . '</h2>';
										}
										if ($section_content) {
											echo '<p>' . esc_html($section_content) . '</p>';
										}
										?>
									</div>
									<div class="btn">
										<?php echo $button_one; ?>
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
		<?php } elseif ($form_style == 'style-three') { ?>
			<div class="lovelove-rsvp-form wpo-contact-section-s4">
				<div class="container">
					<div class="row align-items-center">
						<div class="col col-lg-12 col-md-12 col-12">
							<div class="wpo-contact-section-wrapper">
								<div class="wpo-contact-section-inner">
									<div class="wpo-contact-form-area">
										<div class="wpo-section-title">
											<?php
											if ($section_title) {
												echo '<h4>' . esc_html($section_title) . '</h4>';
											}
											?>
										</div>
										<div class="lovelove-form">
											<?php echo do_shortcode('[contact-form-7 id="' . $form_id . '"]'); ?>
										</div>
									</div>
								</div>
								<div class="shape-1">
									<?php if ($shape_url) {
										echo '<img src="' . esc_url($shape_url) . '" alt="' . esc_attr($shape_alt) . '">';
									} ?>
								</div>
								<div class="shape-2">
									<?php if ($shape2_url) {
										echo '<img src="' . esc_url($shape2_url) . '" alt="' . esc_attr($shape2_alt) . '">';
									} ?>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
		<?php } else { ?>
			<div class="lovelove-rsvp-form wpo-contact-section-s5">
				<div class="container">
					<div class="row align-items-center">
						<div class="col col-lg-10 col-md-12 col-12">
							<div class="wpo-contact-section-wrapper">
								<div class="wpo-contact-section-inner">
									<div class="wpo-contact-form-area">
										<div class="wpo-section-title">
											<?php
											if ($section_title) {
												echo '<h4>' . esc_html($section_title) . '</h4>';
											}
											?>
										</div>
										<div class="lovelove-form">
											<?php echo do_shortcode('[contact-form-7 id="' . $form_id . '"]'); ?>
										</div>
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
<?php }
		// Return outbut buffer
		echo ob_get_clean();
	}



	/**
	 * Render Contact Form widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 */

	//protected function _content_template(){}

}
Plugin::instance()->widgets_manager->register(new Lovelove_Contact_Form());
