<?php
/*
 * Elementor Lovelove Coundown_Hero Widget
 * Author & Copyright: wpoceans
*/

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Lovelove_Coundown_Hero extends Widget_Base
{

	/**
	 * Retrieve the widget name.
	 */
	public function get_name()
	{
		return 'wpo-lovelove_coundown_hero';
	}

	/**
	 * Retrieve the widget title.
	 */
	public function get_title()
	{
		return esc_html__('Satatic Hero', 'lovelove-core');
	}

	/**
	 * Retrieve the widget icon.
	 */
	public function get_icon()
	{
		return 'eicon-countdown';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 */
	public function get_categories()
	{
		return ['wpoceans-category'];
	}

	/**
	 * Retrieve the list of scripts the Lovelove Coundown_Hero widget depended on.
	 * Used to set scripts dependencies required to run the widget.
	 */
	public function get_script_depends()
	{
		return ['wpo-lovelove_coundown_hero'];
	}

	/**
	 * Register Lovelove Coundown_Hero widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 */
	protected function register_controls()
	{

		$this->start_controls_section(
			'section_coundown_hero',
			[
				'label' => esc_html__('Hero Options', 'lovelove-core'),
			]
		);
		$this->add_control(
			'hero_style',
			[
				'label' => esc_html__('Hero Style', 'lovelove-core'),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'style-one' => esc_html__('Style One', 'lovelove-core'),
					'style-two' => esc_html__('Style Two', 'lovelove-core'),
				],
				'default' => 'style-one',
				'description' => esc_html__('Select your coundown style.', 'lovelove-core'),
			]
		);
		$this->add_control(
			'hero_title',
			[
				'label' => esc_html__('Title Text', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__('Title Text Here ', 'lovelove-core'),
				'placeholder' => esc_html__('Type title text here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$this->add_control(
			'hero_content',
			[
				'label' => esc_html__('Content', 'lovelove-core'),
				'default' => esc_html__('your content text', 'lovelove-core'),
				'placeholder' => esc_html__('Type your content here', 'lovelove-core'),
				'type' => Controls_Manager::TEXTAREA,
				'label_block' => true,
			]
		);
		$this->add_control(
			'countdown_date',
			[
				'label' => esc_html__('Countdown Date', 'lovelove-core'),
				'type' => Controls_Manager::DATE_TIME,
				'default' => date("Y-m-d", strtotime("+ 1 day")),
				'description' => esc_html__('Set the due date and time', 'lovelove-core'),
			]
		);
		$this->add_control(
			'countdown_days',
			[
				'label' => esc_html__('Countdown Days', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__('Days', 'lovelove-core'),
				'placeholder' => esc_html__('Type Days text here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$this->add_control(
			'countdown_hours',
			[
				'label' => esc_html__('Countdown Hours', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__('Hours', 'lovelove-core'),
				'placeholder' => esc_html__('Type Hours text here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$this->add_control(
			'countdown_mins',
			[
				'label' => esc_html__('Countdown Mins', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__('Mins', 'lovelove-core'),
				'placeholder' => esc_html__('Type Mins text here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$this->add_control(
			'countdown_secs',
			[
				'label' => esc_html__('Countdown Secs', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__('Secs', 'lovelove-core'),
				'placeholder' => esc_html__('Type Secs text here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$this->add_control(
			'title_shape',
			[
				'label' => esc_html__('Shape Image', 'lovelove-core'),
				'type' => Controls_Manager::MEDIA,
				'condition' => [
					'hero_style' => array('style-two'),
				],
				'frontend_available' => true,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'description' => esc_html__('Set Shape image for Title.', 'lovelove-core'),
			]
		);
		$this->add_control(
			'title_shape2',
			[
				'label' => esc_html__('Shape Image', 'lovelove-core'),
				'type' => Controls_Manager::MEDIA,
				'condition' => [
					'hero_style' => array('style-two'),
				],
				'frontend_available' => true,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'description' => esc_html__('Set Shape image for Title.', 'lovelove-core'),
			]
		);
		$this->add_control(
			'hero_image',
			[
				'label' => esc_html__('Hero Image', 'lovelove-core'),
				'type' => Controls_Manager::MEDIA,
				'frontend_available' => true,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'description' => esc_html__('Set Hero image for Title.', 'lovelove-core'),
			]
		);
		$this->add_control(
			'hero_image2',
			[
				'label' => esc_html__('Hero Image 2', 'lovelove-core'),
				'type' => Controls_Manager::MEDIA,
				'frontend_available' => true,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'description' => esc_html__('Set Hero image for Title.', 'lovelove-core'),
			]
		);
		$this->add_control(
			'hero_image3',
			[
				'label' => esc_html__('Hero Image 3', 'lovelove-core'),
				'type' => Controls_Manager::MEDIA,
				'condition' => [
					'hero_style' => array('style-one'),
				],
				'frontend_available' => true,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'description' => esc_html__('Set Hero image for Title.', 'lovelove-core'),
			]
		);
		$this->end_controls_section(); // end: Section



		// Title
		$this->start_controls_section(
			'section_title_style',
			[
				'label' => esc_html__('Title', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Typography', 'lovelove-core'),
				'name' => 'lovelove_title_typography',
				'selector' => '{{WRAPPER}} .wpo-static-hero .wpo-hero-date h2, .static-hero-s2 h2',
			]
		);
		$this->add_control(
			'title_color',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-static-hero .wpo-hero-date h2, .static-hero-s2 h2' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'title_padding',
			[
				'label' => esc_html__('Title Padding', 'lovelove-core'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em'],
				'selectors' => [
					'{{WRAPPER}} .wpo-static-hero .wpo-hero-date h2, .static-hero-s2 h2' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section

		// Content
		$this->start_controls_section(
			'section_content_style',
			[
				'label' => esc_html__('Content', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Typography', 'lovelove-core'),
				'name' => 'section_content_typography',
				'selector' => '{{WRAPPER}} .wpo-static-hero .wpo-hero-date p, .static-hero-s2 p',
			]
		);
		$this->add_control(
			'content_color',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-static-hero .wpo-hero-date p, .static-hero-s2 p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section


		// Counter Number
		$this->start_controls_section(
			'counter_number_style',
			[
				'label' => esc_html__('Number', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'hero_style' => array('style-two'),
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Typography', 'lovelove-core'),
				'name' => 'lovelove_number_typography',
				'selector' => '{{WRAPPER}} .wpo-wedding-date #clock .time',
			]
		);
		$this->add_control(
			'number_color',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-wedding-date #clock .time' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'number_padding',
			[
				'label' => esc_html__('Number Padding', 'lovelove-core'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em'],
				'selectors' => [
					'{{WRAPPER}} .wpo-wedding-date #clock .time' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section

		// Counter Title
		$this->start_controls_section(
			'counter_title_style',
			[
				'label' => esc_html__('Counter Title', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'hero_style' => array('style-two'),
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Typography', 'lovelove-core'),
				'name' => 'ntrsvt_counter_title_typography',
				'selector' => '{{WRAPPER}} .wpo-wedding-date #clock span',
			]
		);
		$this->add_control(
			'counter_title',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-wedding-date #clock span' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section


	}

	/**
	 * Render Coundown_Hero widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 */
	protected function render()
	{
		$settings = $this->get_settings_for_display();
		$hero_style = !empty($settings['hero_style']) ? $settings['hero_style'] : '';

		$hero_title = !empty($settings['hero_title']) ? $settings['hero_title'] : '';
		$hero_content = !empty($settings['hero_content']) ? $settings['hero_content'] : '';
		$countdown_date = !empty($settings['countdown_date']) ? $settings['countdown_date'] : '';

		$bg_title = !empty($settings['title_shape']['id']) ? $settings['title_shape']['id'] : '';
		$bg_title2 = !empty($settings['title_shape2']['id']) ? $settings['title_shape2']['id'] : '';

		$bg_hero = !empty($settings['hero_image']['id']) ? $settings['hero_image']['id'] : '';
		$bg_hero2 = !empty($settings['hero_image2']['id']) ? $settings['hero_image2']['id'] : '';
		$bg_hero3 = !empty($settings['hero_image3']['id']) ? $settings['hero_image3']['id'] : '';

		// Shape Image
		$hero_url = wp_get_attachment_url($bg_hero);
		$hero_alt = get_post_meta($bg_hero, '_wp_attachment_image_alt', true);

		$hero2_url = wp_get_attachment_url($bg_hero2);
		$hero2_alt = get_post_meta($bg_hero2, '_wp_attachment_image_alt', true);

		$hero3_url = wp_get_attachment_url($bg_hero3);
		$hero3_alt = get_post_meta($bg_hero3, '_wp_attachment_image_alt', true);

		$shape_url = wp_get_attachment_url($bg_title);
		$shape_alt = get_post_meta($bg_title, '_wp_attachment_image_alt', true);

		$shape2_url = wp_get_attachment_url($bg_title2);
		$shape2_alt = get_post_meta($bg_title2, '_wp_attachment_image_alt', true);

		$countdown_days = !empty($settings['countdown_days']) ? $settings['countdown_days'] : '';
		$countdown_hours = !empty($settings['countdown_hours']) ? $settings['countdown_hours'] : '';
		$countdown_mins = !empty($settings['countdown_mins']) ? $settings['countdown_mins'] : '';
		$countdown_secs = !empty($settings['countdown_secs']) ? $settings['countdown_secs'] : '';

		// Turn output buffer on
		ob_start();
		if ($hero_style == 'style-one') { ?>
			<div class="wpo-static-hero">
				<div class="container-fluid">
					<div class="wpo-hero-date">
						<?php
						if ($hero_title) {
							echo '<h2>' . esc_html($hero_title) . '</h2>';
						}
						if ($hero_content) {
							echo '<p>' . esc_html($hero_content) . '</p>';
						}
						?>
					</div>
					<div class="wpo-hero-img-wrap">
						<div class="row">

							<div class="col col-lg-4 col-md-4 col-sm-6 col-12">
								<div class="wpo-hero-img">
									<?php if ($hero_url) {
										echo '<img src="' . esc_url($hero_url) . '" alt="' . esc_attr($hero_alt) . '">';
									} ?>
								</div>
							</div>

							<div class="col col-lg-4 col-md-4 col-sm-6 col-12">
								<div class="wpo-hero-img">
									<?php if ($hero2_url) {
										echo '<img src="' . esc_url($hero2_url) . '" alt="' . esc_attr($hero2_alt) . '">';
									} ?>
								</div>
							</div>

							<div class="col col-lg-4 col-md-4 col-sm-6 col-12">
								<div class="wpo-hero-img">
									<?php if ($hero3_url) {
										echo '<img src="' . esc_url($hero3_url) . '" alt="' . esc_attr($hero3_alt) . '">';
									} ?>
								</div>
							</div>

						</div>
					</div>
				</div>
			</div>
		<?php } else { ?>
			<div class="static-hero-s2">
				<div class="hero-container">
					<div class="hero-inner">
						<div class="container-fluid">
							<div class="row align-items-center">
								<div class="col-xl-6 col-lg-6 col-12">
									<div class="wpo-static-hero-inner">
										<div class="shape-1">
											<?php if ($shape_url) {
												echo '<img src="' . esc_url($shape_url) . '" alt="' . esc_attr($shape_alt) . '">';
											} ?>
										</div>

										<div data-swiper-parallax="300" class="slide-title">
											<?php
											if ($hero_title) {
												echo '<h2>' . esc_html($hero_title) . '</h2>';
											}
											?>
										</div>
										<div data-swiper-parallax="400" class="slide-text">
											<?php
											if ($hero_content) {
												echo '<p>' . esc_html($hero_content) . '</p>';
											}
											?>
										</div>

										<div class="wpo-wedding-date">
											<div class="clock-grids">
												<div id="clock" data-date="<?php echo esc_attr($countdown_date); ?>"></div>
											</div>
										</div>

										<div class="shape-2">
											<?php if ($shape2_url) {
												echo '<img src="' . esc_url($shape2_url) . '" alt="' . esc_attr($shape2_alt) . '">';
											} ?>
										</div>
										<div class="clearfix"></div>
									</div>
								</div>
								<div class="col-xl-6 col-lg-6 col-12">
									<div class="static-hero-right">
										<div class="static-hero-img">
											<div class="static-hero-img-inner">
												<?php if ($hero_url) {
													echo '<img src="' . esc_url($hero_url) . '" alt="' . esc_attr($hero_alt) . '">';
												} ?>
											</div>
										</div>
										<div class="static-hero-shape">
											<?php if ($hero2_url) {
												echo '<img src="' . esc_url($hero2_url) . '" alt="' . esc_attr($hero2_alt) . '">';
											} ?>
										</div>
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>

			<div class="wpo-coundown wpo-wedding-date">
				<div class="container">
					<div class="clock-grids">
						<div id="clock" data-date="<?php echo esc_attr($countdown_date); ?>"></div>
					</div>
				</div>
			</div>

			<script>
				jQuery(document).ready(function() {
					/*------------------------------------------
            = COUNTDOWN CLOCK
        -------------------------------------------*/
					if (jQuery("#clock").length) {
						var weddingDate = jQuery('#clock').data('date');
						jQuery('#clock').countdown(weddingDate, function(event) {
							var $this = jQuery(this).html(event.strftime('' +
								'<div class="box"><div><div class="time">%m</div><span>Month</span></div></div>' +
								'<div class="box"><div><div class="time">%D</div> <span><?php echo esc_html($countdown_days); ?></span></div></div>' +
								'<div class="box"><div><div class="time">%H</div> <span><?php echo esc_html($countdown_hours); ?></span></div></div>' +
								'<div class="box"><div><div class="time">%M</div> <span><?php echo esc_html($countdown_mins); ?></span> </div></div>' +
								'<div class="box"><div><div class="time">%S</div> <span><?php echo esc_html($countdown_secs); ?></span> </div></div>'));
						});
					}

				});
			</script>
<?php }
		// Return outbut buffer
		echo ob_get_clean();
	}
	/**
	 * Render Coundown_Hero widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 */

	//protected function _content_template(){}

}
Plugin::instance()->widgets_manager->register(new Lovelove_Coundown_Hero());
