<?php
/*
 * Elementor Lovelove Coundown Widget
 * Author & Copyright: wpoceans
*/

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Lovelove_Coundown extends Widget_Base
{

	/**
	 * Retrieve the widget name.
	 */
	public function get_name()
	{
		return 'wpo-lovelove_coundown';
	}

	/**
	 * Retrieve the widget title.
	 */
	public function get_title()
	{
		return esc_html__('Coundown Clock', 'lovelove-core');
	}

	/**
	 * Retrieve the widget icon.
	 */
	public function get_icon()
	{
		return 'eicon-countdown';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 */
	public function get_categories()
	{
		return ['wpoceans-category'];
	}

	/**
	 * Retrieve the list of scripts the Lovelove Coundown widget depended on.
	 * Used to set scripts dependencies required to run the widget.
	 */
	public function get_script_depends()
	{
		return ['wpo-lovelove_coundown'];
	}

	/**
	 * Register Lovelove Coundown widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 */
	protected function register_controls()
	{

		$this->start_controls_section(
			'section_coundown_clock',
			[
				'label' => esc_html__('Hero Options', 'lovelove-core'),
			]
		);
		$this->add_control(
			'countdown_date',
			[
				'label' => esc_html__('Countdown Date', 'lovelove-core'),
				'type' => Controls_Manager::DATE_TIME,
				'default' => date("Y-m-d", strtotime("+ 1 day")),
				'description' => esc_html__('Set the due date and time', 'lovelove-core'),
			]
		);
		$this->add_control(
			'countdown_days',
			[
				'label' => esc_html__('Countdown Days', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__('Days', 'lovelove-core'),
				'placeholder' => esc_html__('Type Days text here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$this->add_control(
			'countdown_hours',
			[
				'label' => esc_html__('Countdown Hours', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__('Hours', 'lovelove-core'),
				'placeholder' => esc_html__('Type Hours text here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$this->add_control(
			'countdown_mins',
			[
				'label' => esc_html__('Countdown Mins', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__('Mins', 'lovelove-core'),
				'placeholder' => esc_html__('Type Mins text here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$this->add_control(
			'countdown_secs',
			[
				'label' => esc_html__('Countdown Secs', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__('Secs', 'lovelove-core'),
				'placeholder' => esc_html__('Type Secs text here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$this->end_controls_section(); // end: Section


		// Counter Number
		$this->start_controls_section(
			'counter_number_style',
			[
				'label' => esc_html__('Number', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Typography', 'lovelove-core'),
				'name' => 'lovelove_number_typography',
				'selector' => '{{WRAPPER}} .wpo-wedding-date #clock .time',
			]
		);
		$this->add_control(
			'number_color',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-wedding-date #clock .time' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'number_padding',
			[
				'label' => esc_html__('Number Padding', 'lovelove-core'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em'],
				'selectors' => [
					'{{WRAPPER}} .wpo-wedding-date #clock .time' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section

		// Counter Title
		$this->start_controls_section(
			'counter_title_style',
			[
				'label' => esc_html__('Counter Title', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Typography', 'lovelove-core'),
				'name' => 'ntrsvt_counter_title_typography',
				'selector' => '{{WRAPPER}} .wpo-wedding-date #clock span',
			]
		);
		$this->add_control(
			'counter_title',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-wedding-date #clock span' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section


	}

	/**
	 * Render Coundown widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 */
	protected function render()
	{
		$settings = $this->get_settings_for_display();
		$countdown_date = !empty($settings['countdown_date']) ? $settings['countdown_date'] : '';
		// Turn output buffer on
		$countdown_days = !empty($settings['countdown_days']) ? $settings['countdown_days'] : '';
		$countdown_hours = !empty($settings['countdown_hours']) ? $settings['countdown_hours'] : '';
		$countdown_mins = !empty($settings['countdown_mins']) ? $settings['countdown_mins'] : '';
		$countdown_secs = !empty($settings['countdown_secs']) ? $settings['countdown_secs'] : '';

		ob_start(); ?>

		<div class="lovelove-condown-date wpo-wedding-date">

			<div class="clock-grids">
				<div id="clock" data-date="<?php echo esc_attr($countdown_date); ?>"></div>
			</div>

		</div>

		<script>
			jQuery(document).ready(function() {
				/*------------------------------------------
            = COUNTDOWN CLOCK
        -------------------------------------------*/
				if (jQuery("#clock").length) {
					var weddingDate = jQuery('#clock').data('date');
					jQuery('#clock').countdown(weddingDate, function(event) {
						var $this = jQuery(this).html(event.strftime('' +
							'<div class="box"><div><div class="time">%m</div><span>Month</span></div></div>' +
							'<div class="box"><div><div class="time">%D</div> <span><?php echo esc_html($countdown_days); ?></span></div></div>' +
							'<div class="box"><div><div class="time">%H</div> <span><?php echo esc_html($countdown_hours); ?></span></div></div>' +
							'<div class="box"><div><div class="time">%M</div> <span><?php echo esc_html($countdown_mins); ?></span> </div></div>' +
							'<div class="box"><div><div class="time">%S</div> <span><?php echo esc_html($countdown_secs); ?></span> </div></div>'));
					});
				}

			});
		</script>
<?php
		// Return outbut buffer
		echo ob_get_clean();
	}
	/**
	 * Render Coundown widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 */

	//protected function _content_template(){}

}
Plugin::instance()->widgets_manager->register(new Lovelove_Coundown());
