<?php
/*
 * Elementor Lovelove Couple Widget
 * Author & Copyright: wpoceans
*/

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Lovelove_Couple_Hero extends Widget_Base
{

	/**
	 * Retrieve the widget name.
	 */
	public function get_name()
	{
		return 'wpo-lovelove_couple_hero';
	}

	/**
	 * Retrieve the widget title.
	 */
	public function get_title()
	{
		return esc_html__('Couple', 'lovelove-core');
	}

	/**
	 * Retrieve the widget icon.
	 */
	public function get_icon()
	{
		return 'eicon-cogs-check';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 */
	public function get_categories()
	{
		return ['wpoceans-category'];
	}

	/**
	 * Retrieve the list of scripts the Lovelove Couple widget depended on.
	 * Used to set scripts dependencies required to run the widget.
	 */
	public function get_script_depends()
	{
		return ['wpo-lovelove_couple_hero'];
	}

	/**
	 * Register Lovelove Couple widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 */
	protected function register_controls()
	{

		$this->start_controls_section(
			'couple_hero_section',
			[
				'label' => esc_html__('Couple Hero', 'lovelove-core'),
			]
		);
		$this->add_control(
			'couple_style',
			[
				'label' => esc_html__('Couple Style', 'lovelove-core'),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'style-one' => esc_html__('Style One', 'lovelove-core'),
					'style-two' => esc_html__('Style Two', 'lovelove-core'),
					'style-three' => esc_html__('Style Three', 'lovelove-core'),
					'style-four' => esc_html__('Style Four', 'lovelove-core'),
				],
				'default' => 'style-one',
				'description' => esc_html__('Select your couple style.', 'lovelove-core'),
			]
		);
		$this->add_control(
			'section_title',
			[
				'label' => esc_html__('Title Text', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'condition' => [
					'couple_style' => array('style-four'),
				],
				'default' => esc_html__('Title Text', 'lovelove-core'),
				'placeholder' => esc_html__('Type title text here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$this->add_control(
			'section_content',
			[
				'label' => esc_html__('Content Text', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'condition' => [
					'couple_style' => array('style-four'),
				],
				'default' => esc_html__('Content Text', 'lovelove-core'),
				'placeholder' => esc_html__('Type content text here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$this->add_control(
			'cuple_image',
			[
				'label' => esc_html__('Couple Image', 'lovelove-core'),
				'type' => Controls_Manager::MEDIA,
				'frontend_available' => true,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'description' => esc_html__('Set Couple image here.', 'lovelove-core'),
			]
		);
		$this->add_control(
			'cuple_shape1',
			[
				'label' => esc_html__('Couple Shape', 'lovelove-core'),
				'type' => Controls_Manager::MEDIA,
				'condition' => [
					'couple_style' => array('style-two', 'style-four'),
				],
				'frontend_available' => true,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'description' => esc_html__('Set Couple Fram here.', 'lovelove-core'),
			]
		);
		$this->add_control(
			'cuple_shape2',
			[
				'label' => esc_html__('Background', 'lovelove-core'),
				'type' => Controls_Manager::MEDIA,
				'condition' => [
					'couple_style' => array('style-four'),
				],
				'frontend_available' => true,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'description' => esc_html__('Set Shape image here.', 'lovelove-core'),
			]
		);
		$this->end_controls_section(); // end: Section

		$this->start_controls_section(
			'section_bride',
			[
				'label' => esc_html__('Bride Options', 'lovelove-core'),
			]
		);
		$this->add_control(
			'bride_shape',
			[
				'label' => esc_html__('Bride Image', 'lovelove-core'),
				'type' => Controls_Manager::MEDIA,
				'frontend_available' => true,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'description' => esc_html__('Set Bride shape here.', 'lovelove-core'),
			]
		);
		$this->add_control(
			'bride_title',
			[
				'label' => esc_html__('Title Text', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__('Title Text', 'lovelove-core'),
				'placeholder' => esc_html__('Type title text here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$this->add_control(
			'bride_content',
			[
				'label' => esc_html__('Content Text', 'lovelove-core'),
				'type' => Controls_Manager::TEXTAREA,
				'default' => esc_html__('Content Text', 'lovelove-core'),
				'placeholder' => esc_html__('Type content text here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$repeater = new Repeater();
		$repeater->add_control(
			'bride_social_icon',
			[
				'label' => __('Icon', 'oule-core'),
				'type' => \Elementor\Controls_Manager::ICONS,
				'default' => [
					'value' => 'ti-twitter-alt',
					'library' => 'solid',
				],
			]
		);
		$repeater->add_control(
			'bride_social_link',
			[
				'label' => esc_html__('Social Link', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__('Social Link', 'lovelove-core'),
				'placeholder' => esc_html__('Type social link here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$this->add_control(
			'bride_socialItems_groups',
			[
				'label' => esc_html__('Social Item', 'lovelove-core'),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'bride_social_icon' => esc_html__('Social', 'lovelove-core'),
					],

				],
				'fields' =>  $repeater->get_controls(),
				'title_field' => '{{{ bride_social_link }}}',
			]
		);
		$this->end_controls_section(); // end: Section

		$this->start_controls_section(
			'section_groom',
			[
				'label' => esc_html__('Groom Options', 'lovelove-core'),
			]
		);
		$this->add_control(
			'groom_shape',
			[
				'label' => esc_html__('Groom Image', 'lovelove-core'),
				'type' => Controls_Manager::MEDIA,
				'frontend_available' => true,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'description' => esc_html__('Set Groom image here.', 'lovelove-core'),
			]
		);
		$this->add_control(
			'groom_title',
			[
				'label' => esc_html__('Groom Title Text', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__('Title Text', 'lovelove-core'),
				'placeholder' => esc_html__('Type title text here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$this->add_control(
			'groom_content',
			[
				'label' => esc_html__('Groom Content Text', 'lovelove-core'),
				'type' => Controls_Manager::TEXTAREA,
				'default' => esc_html__('Content Text', 'lovelove-core'),
				'placeholder' => esc_html__('Type content text here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$repeater = new Repeater();
		$repeater->add_control(
			'groom_social_icon',
			[
				'label' => __('Icon', 'oule-core'),
				'type' => \Elementor\Controls_Manager::ICONS,
				'default' => [
					'value' => 'ti-twitter-alt',
					'library' => 'solid',
				],
			]
		);
		$repeater->add_control(
			'groom_social_link',
			[
				'label' => esc_html__('Social Link', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__('Social Link', 'lovelove-core'),
				'placeholder' => esc_html__('Type social link here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$this->add_control(
			'groom_socialItems_groups',
			[
				'label' => esc_html__('Social Item', 'lovelove-core'),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'groom_social_icon' => esc_html__('Social', 'lovelove-core'),
					],

				],
				'fields' =>  $repeater->get_controls(),
				'title_field' => '{{{ groom_social_link }}}',
			]
		);
		$this->end_controls_section(); // end: Section

		// Title
		$this->start_controls_section(
			'section_couple_title_style',
			[
				'label' => esc_html__('Section Title', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'couple_style' => array('style-four'),
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'lovelove_couple_title_typography',
				'selector' => '{{WRAPPER}} .static-hero-s3 .wpo-hero-date h2',
			]
		);
		$this->add_control(
			'couple_title_color',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .static-hero-s3 .wpo-hero-date h2' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'couple_title_padding',
			[
				'label' => esc_html__('Title Padding', 'lovelove-core'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors' => [
					'{{WRAPPER}} .static-hero-s3 .wpo-hero-date h2' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section

		// subtitle
		$this->start_controls_section(
			'section_couple_subtitle_style',
			[
				'label' => esc_html__('Section Sub Title', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'couple_style' => array('style-four'),
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'lovelove_couple_subtitle_typography',
				'selector' => '{{WRAPPER}} .static-hero-s3 .wpo-hero-date p',
			]
		);
		$this->add_control(
			'couple_subtitle_color',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .static-hero-s3 .wpo-hero-date p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'couple_subtitle_padding',
			[
				'label' => esc_html__('Title Padding', 'lovelove-core'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors' => [
					'{{WRAPPER}} .static-hero-s3 .wpo-hero-date p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section

		// Border
		$this->start_controls_section(
			'section_border_style',
			[
				'label' => esc_html__('Border', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'couple_style' => array('style-three'),
				],
			]
		);
		$this->add_control(
			'border_color',
			[
				'label' => esc_html__('Border Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-couple-section-s3 .couple-area .couple-item .couple-img::before, .wpo-couple-section-s3 .couple-area .couple-item .couple-img::after' => 'border-color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section

		// Title
		$this->start_controls_section(
			'section_title_style',
			[
				'label' => esc_html__('Title', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Typography', 'lovelove-core'),
				'name' => 'lovelove_title_typography',
				'selector' => '{{WRAPPER}} .lovelove-couple .couple-area .couple-item .couple-text h3',
			]
		);
		$this->add_control(
			'title_color',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lovelove-couple .couple-area .couple-item .couple-text h3' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'title_padding',
			[
				'label' => __('Title Padding', 'lovelove-core'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em'],
				'selectors' => [
					'{{WRAPPER}} .lovelove-couple .couple-area .couple-item .couple-text h3' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section


		// Couple Content
		$this->start_controls_section(
			'couple_content_style',
			[
				'label' => esc_html__('Content', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Typography', 'lovelove-core'),
				'name' => 'lovelove_couple_hero_content_typography',
				'selector' => '{{WRAPPER}} .lovelove-couple .couple-area .couple-item .couple-text p',
			]
		);
		$this->add_control(
			'couple_content',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lovelove-couple .couple-area .couple-item .couple-text p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'couple_content_padding',
			[
				'label' => esc_html__('Number Padding', 'lovelove-core'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em'],
				'selectors' => [
					'{{WRAPPER}} .lovelove-couple .couple-area .couple-item .couple-text p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section

		// Icon
		$this->start_controls_section(
			'section_icon_style',
			[
				'label' => esc_html__('Icon', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Typography', 'lovelove-core'),
				'name' => 'sasban_icon_typography',
				'selector' => '{{WRAPPER}} .lovelove-couple .couple-area .couple-item .couple-text ul li a i:before',
			]
		);
		$this->add_control(
			'icon_color',
			[
				'label' => esc_html__('Icon Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lovelove-couple .couple-area .couple-item .couple-text ul li a i:before' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section

		// Icon Hover
		$this->start_controls_section(
			'section_icon_hover_style',
			[
				'label' => esc_html__('Hover', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'icon_hover_color',
			[
				'label' => esc_html__('Icon Hover Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lovelove-couple .couple-area .couple-item .couple-text ul li a:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section


	}

	/**
	 * Render Couple widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 */
	protected function render()
	{
		$settings = $this->get_settings_for_display();
		$couple_style = !empty($settings['couple_style']) ? $settings['couple_style'] : '';
		$section_title = !empty($settings['section_title']) ? $settings['section_title'] : '';
		$section_content = !empty($settings['section_content']) ? $settings['section_content'] : '';
		// Couple Image
		$couple_image = !empty($settings['cuple_image']['id']) ? $settings['cuple_image']['id'] : '';
		$couple_url = wp_get_attachment_url($couple_image);
		$couple_alt = get_post_meta($couple_image, '_wp_attachment_image_alt', true);

		// Couple Image
		$shape_image = !empty($settings['cuple_shape1']['id']) ? $settings['cuple_shape1']['id'] : '';
		$shape_url = wp_get_attachment_url($shape_image);
		$shape_alt = get_post_meta($shape_image, '_wp_attachment_image_alt', true);

		// BG Shape
		$shape2_image = !empty($settings['cuple_shape2']['id']) ? $settings['cuple_shape2']['id'] : '';
		$shape2_url = wp_get_attachment_url($shape2_image);
		$shape2_alt = get_post_meta($shape2_image, '_wp_attachment_image_alt', true);

		// bride_shape
		$bride_shape = !empty($settings['bride_shape']['id']) ? $settings['bride_shape']['id'] : '';
		$bride_url = wp_get_attachment_url($bride_shape);
		$bride_alt = get_post_meta($settings['bride_shape']['id'], '_wp_attachment_image_alt', true);

		$bride_title = !empty($settings['bride_title']) ? $settings['bride_title'] : '';
		$bride_content = !empty($settings['bride_content']) ? $settings['bride_content'] : '';
		$bride_socialItems_groups = !empty($settings['bride_socialItems_groups']) ? $settings['bride_socialItems_groups'] : '';

		// groom_shape
		$groom_shape = !empty($settings['groom_shape']['id']) ? $settings['groom_shape']['id'] : '';
		$groom_url = wp_get_attachment_url($groom_shape);
		$groom_alt = get_post_meta($settings['groom_shape']['id'], '_wp_attachment_image_alt', true);

		$groom_title = !empty($settings['groom_title']) ? $settings['groom_title'] : '';
		$groom_content = !empty($settings['groom_content']) ? $settings['groom_content'] : '';
		$groom_socialItems_groups = !empty($settings['groom_socialItems_groups']) ? $settings['groom_socialItems_groups'] : '';

		if ($couple_style == 'style-one') {
			$couple_wrapper = 'wpo-couple-section';
			$couple_col = 'col-md-5 col-12';
		} elseif ($couple_style == 'style-two') {
			$couple_wrapper = 'wpo-couple-section-s2';
			$couple_col = 'col-lg-4 col-md-6 col-12';
		} elseif ($couple_style == 'style-three') {
			$couple_wrapper = 'wpo-couple-section-s3';
			$couple_col = 'col-md-4 col-12';
		} else {
			$couple_wrapper = 'wpo-couple-section-s4';
			$couple_col = 'col-md-4 col-12';
		}

		if ($couple_style == 'style-two') {
			$couple_row = 'justify-content-center';
		} else {
			$couple_row = '';
		}

		if ($couple_style == 'style-three') {
			$couple_row_justyfy = '';
		} else {
			$couple_row_justyfy = ' align-items-center';
		}

		if ($couple_style == 'style-one') {
			$couple_middle_col = 'col-md-2';
		} else {
			$couple_middle_col = 'col-md-4';
		}

		if ($shape2_url) {
			$bg_url = ' style="';
			$bg_url .= ($shape2_url) ? 'background-image: url( ' . esc_url($shape2_url) . ' );' : '';
			$bg_url .= '"';
		} else {
			$bg_url = '';
		}

		// Turn output buffer on
		ob_start(); ?>

		<?php if ($couple_style == 'style-four') { ?>
			<div class="static-hero-s3" <?php echo $bg_url; ?>>
				<div class="container-fluid">
					<div class="wpo-hero-date">
						<?php
						if ($section_title) {
							echo '<h2>' . esc_html($section_title) . '</h2>';
						}
						if ($section_content) {
							echo '<p>' . esc_html($section_content) . '</p>';
						}
						?>
					</div>
				</div>
			</div>
		<?php } ?>
		<div class="lovelove-couple <?php echo esc_attr($couple_wrapper); ?>">
			<div class="container">
				<div class="couple-area clearfix">
					<?php if ($couple_style == 'style-two') { ?>
						<div class="shape-1">
							<?php if ($couple_url) {
								echo '<img src="' . esc_url($couple_url) . '" alt="' . esc_attr($couple_alt) . '">';
							}  ?>
						</div>
						<div class="shape-2">
							<?php if ($shape_url) {
								echo '<img src="' . esc_url($shape_url) . '" alt="' . esc_attr($shape_alt) . '">';
							}  ?>
						</div>
					<?php } ?>
					<div class="row <?php echo esc_attr($couple_row . $couple_row_justyfy); ?>">
						<div class="col <?php echo esc_attr($couple_col); ?>">
							<div class="couple-item">
								<?php if ($bride_url) : ?>
									<div class="couple-img">
										<img src="<?php echo esc_url($bride_url); ?>" alt="<?php echo esc_attr($bride_url); ?>">
									</div>
								<?php endif; ?>
								<div class="couple-text">
									<?php
									if ($bride_title) {
										echo '<h3>' . esc_html($bride_title) . '</h3>';
									}
									if ($bride_content) {
										echo '<p>' . $bride_content . '</p>';
									}
									?>
									<div class="social">
										<ul>
											<?php  	// Group Param Output
											if (is_array($bride_socialItems_groups) && !empty($bride_socialItems_groups)) {
												foreach ($bride_socialItems_groups as $each_item) {

													$social_link = !empty($each_item['bride_social_link']) ? $each_item['bride_social_link'] : '';

													$bride_icon = !empty($each_item['bride_social_icon']['value']) ? $each_item['bride_social_icon']['value'] : '';
													$bride_svg_url = !empty($each_item['bride_social_icon']['value']['url']) ? $each_item['bride_social_icon']['value']['url'] : '';
													$svg_alt = get_post_meta($bride_svg_url, '_wp_attachment_image_alt', true);

											?>
													<li>
														<a href="<?php echo esc_url($social_link); ?>">
															<?php
															if ($bride_svg_url) {
																echo '<img src="' . esc_url($bride_svg_url) . '" alt="' . esc_url($svg_alt) . '">';
															} else {
																echo '<i class="' . esc_attr($bride_icon) . '"></i>';
															} ?>
														</a>
													</li>
											<?php }
											} ?>
										</ul>
									</div>
								</div>
								<?php if ($couple_style == 'style-two') { ?>
									<div class="round-1"></div>
									<div class="round-2"></div>
									<div class="round-3"></div>
									<div class="layer-1"></div>
									<div class="layer-2"></div>
									<div class="layer-3"></div>
								<?php } ?>

							</div>
						</div>

						<?php if ($couple_style !== 'style-two') { ?>
							<div class="col <?php echo esc_attr($couple_middle_col); ?> col-12">
								<div class="middle-couple-shape">
									<?php if ($couple_style == 'style-four') { ?>
										<div class="middle-img">
											<?php if ($shape_url) {
												echo '<img src="' . esc_url($shape_url) . '" alt="' . esc_attr($shape_alt) . '">';
											}  ?>
										</div>
									<?php } ?>
									<div class="shape">
										<?php if ($couple_url) {
											echo '<img src="' . esc_url($couple_url) . '" alt="' . esc_attr($couple_alt) . '">';
										}  ?>
									</div>
								</div>
							</div>
						<?php } ?>

						<div class="col <?php echo esc_attr($couple_col); ?>">
							<div class="couple-item">
								<?php if ($groom_url) : ?>
									<div class="couple-img">
										<img src="<?php echo esc_url($groom_url); ?>" alt="<?php echo esc_attr($groom_alt); ?>">
									</div>
								<?php endif; ?>
								<div class="couple-text">
									<?php
									if ($groom_title) {
										echo '<h3>' . esc_html($groom_title) . '</h3>';
									}
									if ($groom_content) {
										echo '<p>' . $groom_content . '</p>';
									}
									?>
									<div class="social">
										<ul>
											<?php 	// Group Param Output
											if (is_array($groom_socialItems_groups) && !empty($groom_socialItems_groups)) {
												foreach ($groom_socialItems_groups as $each_item) {

													$social_link = !empty($each_item['groom_social_link']) ? $each_item['groom_social_link'] : '';

													$groom_icon = !empty($each_item['groom_social_icon']['value']) ? $each_item['groom_social_icon']['value'] : '';
													$groom_svg_url = !empty($each_item['groom_social_icon']['value']['url']) ? $each_item['groom_social_icon']['value']['url'] : '';
													$svg_alt = get_post_meta($groom_svg_url, '_wp_attachment_image_alt', true);

											?>
													<li>
														<a href="<?php echo esc_url($social_link); ?>">
															<?php
															if ($groom_svg_url) {
																echo '<img src="' . esc_url($groom_svg_url) . '" alt="' . esc_url($svg_alt) . '">';
															} else {
																echo '<i class="' . esc_attr($groom_icon) . '"></i>';
															} ?>
														</a>
													</li>
											<?php }
											} ?>
										</ul>
									</div>
								</div>

								<?php if ($couple_style == 'style-two') { ?>
									<div class="layer-1"></div>
									<div class="layer-2"></div>
									<div class="layer-3"></div>
								<?php } ?>

							</div>
						</div>

					</div>
				</div>
			</div> <!-- end container -->
		</div>
<?php
		// Return outbut buffer
		echo ob_get_clean();
	}
	/**
	 * Render Couple widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 */

	//protected function _content_template(){}

}
Plugin::instance()->widgets_manager->register(new Lovelove_Couple_Hero());
