<?php
/*
 * Elementor Lovelove Footer_Info Widget
 * Author & Copyright: wpoceans
*/

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Lovelove_Footer_Info extends Widget_Base
{

	/**
	 * Retrieve the widget name.
	 */
	public function get_name()
	{
		return 'wpo-lovelove_footer_info';
	}

	/**
	 * Retrieve the widget footer_info.
	 */
	public function get_title()
	{
		return esc_html__('Footer Info', 'lovelove-core');
	}

	/**
	 * Retrieve the widget icon.
	 */
	public function get_icon()
	{
		return 'eicon-kit-details';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 */
	public function get_categories()
	{
		return ['wpoceans-category'];
	}

	/**
	 * Retrieve the list of scripts the Lovelove Footer_Info widget depended on.
	 * Used to set scripts dependencies required to run the widget.
	 */
	/*
	public function get_script_depends() {
		return ['wpo-lovelove_footer_info'];
	}
	*/

	/**
	 * Register Lovelove Footer_Info widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 */
	protected function register_controls()
	{

		$this->start_controls_section(
			'section_Footer_Info',
			[
				'label' => esc_html__('FooterOptions', 'lovelove-core'),
			]
		);
		$this->add_control(
			'footer_logo',
			[
				'label' => __('Footer Logo', 'lovelove-core'),
				'type' => \Elementor\Controls_Manager::ICONS,
				'default' => [
					'value' => 'fi fi-facebook',
					'library' => 'solid',
				],
			]
		);
		$this->add_control(
			'logo_link',
			[
				'label' => esc_html__('Link', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__('#', 'lovelove-core'),
				'placeholder' => esc_html__('Type Link here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$repeater = new Repeater();
		$repeater->add_control(
			'menu_title',
			[
				'label' => esc_html__('Title', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__('Title', 'lovelove-core'),
				'placeholder' => esc_html__('Type Title here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'menu_link',
			[
				'label' => esc_html__('Link', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__('#', 'lovelove-core'),
				'placeholder' => esc_html__('Type Title link here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$this->add_control(
			'menuItems_groups',
			[
				'label' => esc_html__('Menu Items', 'lovelove-core'),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'menu_title' => esc_html__('Menu', 'lovelove-core'),
					],

				],
				'fields' =>  $repeater->get_controls(),
				'title_field' => '{{{ menu_title }}}',
			]
		);
		$repeater = new Repeater();
		$repeater->add_control(
			'social_icon',
			[
				'label' => __('Social Icon', 'lovelove-core'),
				'type' => \Elementor\Controls_Manager::ICONS,
				'default' => [
					'value' => 'fi fi-facebook',
					'library' => 'solid',
				],
			]
		);
		$repeater->add_control(
			'social_link',
			[
				'label' => esc_html__('Link', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__('#', 'lovelove-core'),
				'placeholder' => esc_html__('Type Title link here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$this->add_control(
			'socialItems_groups',
			[
				'label' => esc_html__('Social Items', 'lovelove-core'),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'social_link' => esc_html__('Social', 'lovelove-core'),
					],

				],
				'fields' =>  $repeater->get_controls(),
				'title_field' => '{{{ social_link }}}',
			]
		);
		$this->end_controls_section(); // end: Section

		// Menu Info
		$this->start_controls_section(
			'section_menu_style',
			[
				'label' => esc_html__('Menu', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Typography', 'lovelove-core'),
				'name' => 'section_menu_typography',
				'selector' => '{{WRAPPER}} .wpo-site-footer .footer-link ul li a',
			]
		);
		$this->add_control(
			'menu_info_color',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-site-footer .footer-link ul li a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'menu_info_dot_color',
			[
				'label' => esc_html__('Dot Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-site-footer .footer-link ul li:before' => 'background-color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'menu_padding',
			[
				'label' => __('Menu Padding', 'lovelove-core'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em'],
				'selectors' => [
					'{{WRAPPER}} .wpo-site-footer .footer-link ul li a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section

		// Social

		// Title
		$this->start_controls_section(
			'section_social_style',
			[
				'label' => esc_html__('Social', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'social_color',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-site-footer .link-widget ul li a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'social_bg_color',
			[
				'label' => esc_html__('BG Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-site-footer .link-widget ul li a' => 'background-color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'social_hover_color',
			[
				'label' => esc_html__('Hover Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-site-footer .link-widget ul li a:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'social_hover_bg_color',
			[
				'label' => esc_html__('Hover BG Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-site-footer .link-widget ul li a:hover' => 'background-color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section

	}

	/**
	 * Render Footer_Info widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 */
	protected function render()
	{
		$settings = $this->get_settings_for_display();
		$menuItems_groups = !empty($settings['menuItems_groups']) ? $settings['menuItems_groups'] : [];
		$socialItems_groups = !empty($settings['socialItems_groups']) ? $settings['socialItems_groups'] : [];

		$footer_logo = !empty($settings['footer_logo']['value']) ? $settings['footer_logo']['value'] : '';
		$footer_svg_url = !empty($settings['footer_logo']['value']['url']) ? $settings['footer_logo']['value']['url'] : '';
		$footer_svg_alt = get_post_meta($footer_svg_url, '_wp_attachment_image_alt', true);

		$logo_link = !empty($settings['logo_link']) ? $settings['logo_link'] : '';

		// Turn output buffer on

		ob_start();
?>
		<div class="wpo-site-footer lovelove-footer-info text-center">
			<div class="container">
				<div class="row">

					<div class="col-12">
						<div class="footer-image">
							<?php if ($logo_link) {
								echo '<a href="' . esc_url($logo_link) . '">';
							} ?>
							<?php
							if ($footer_svg_url) {
								echo '<img class="default-logo-icon"  src="' . esc_url($footer_svg_url) . '" alt="' . esc_url($footer_svg_alt) . '">';
							} else {
								echo '<i class="' . esc_attr($footer_logo) . '"></i>';
							}
							?>
							<?php if ($logo_link) {
								echo '</a>';
							} ?>
						</div>
					</div>

					<div class="col-12">
						<div class="footer-link">
							<ul>
								<?php 	// Group Param Output
								if (is_array($menuItems_groups) && !empty($menuItems_groups)) {
									foreach ($menuItems_groups as $each_item) {

										$menu_title = !empty($each_item['menu_title']) ? $each_item['menu_title'] : '';
										$menu_link = !empty($each_item['menu_link']) ? $each_item['menu_link'] : '';
										if ($menu_title) {
											echo '<li><a href="' . esc_url($menu_link) . '">' . esc_html($menu_title) . '</a></li>';
										}
									}
								}
								?>
							</ul>
						</div>
					</div>

					<div class="col-12">
						<div class="link-widget">

							<ul>
								<?php 	// Group Param Output
								if (is_array($socialItems_groups) && !empty($socialItems_groups)) {
									foreach ($socialItems_groups as $each_item) {

										$social_icon = !empty($each_item['social_icon']['value']) ? $each_item['social_icon']['value'] : '';
										$social_svg_url = !empty($each_item['social_icon']['value']['url']) ? $each_item['social_icon']['value']['url'] : '';
										$svg_alt = get_post_meta($social_svg_url, '_wp_attachment_image_alt', true);

										$social_link = !empty($each_item['social_link']) ? $each_item['social_link'] : '';
										if ($social_link) {
											echo '<li><a href="' . esc_url($social_link) . '">';
										}
										if ($social_svg_url) {
											echo '<img class="default-icon"  src="' . esc_url($social_svg_url) . '" alt="' . esc_url($svg_alt) . '">';
										} else {
											echo '<i class="' . esc_attr($social_icon) . '"></i>';
										}
										if ($social_link) {
											echo '</a></li>';
										}
									}
								}
								?>
							</ul>
						</div>
					</div>

				</div>
			</div>
		</div>
<?php
		// Return outbut buffer
		echo ob_get_clean();
	}
	/**
	 * Render Footer_Info widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 */

	//protected function _content_template(){}

}
Plugin::instance()->widgets_manager->register(new Lovelove_Footer_Info());
