<?php
/*
 * Elementor Lovelove ProjectItem Widget
 * Author & Copyright: wpoceans
*/

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Lovelove_ProjectItem extends Widget_Base
{

	/**
	 * Retrieve the widget name.
	 */
	public function get_name()
	{
		return 'wpo-lovelove_projectitem';
	}

	/**
	 * Retrieve the widget title.
	 */
	public function get_title()
	{
		return esc_html__('Portfolio Single', 'lovelove-core');
	}

	/**
	 * Retrieve the widget icon.
	 */
	public function get_icon()
	{
		return 'eicon-single-post';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 */
	public function get_categories()
	{
		return ['wpoceans-category'];
	}

	/**
	 * Retrieve the list of scripts the Lovelove ProjectItem widget depended on.
	 * Used to set scripts dependencies required to run the widget.
	 */
	/*
	public function get_script_depends() {
		return ['wpo-lovelove_projectitem'];
	}
	*/

	/**
	 * Register Lovelove ProjectItem widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 */
	protected function register_controls()
	{

		$this->start_controls_section(
			'section_ProjectItem',
			[
				'label' => esc_html__('Portfolio Single', 'lovelove-core'),
			]
		);
		$this->add_control(
			'section_title',
			[
				'label' => esc_html__('Title Text', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__('Title Text', 'lovelove-core'),
				'placeholder' => esc_html__('Type title text here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$this->add_control(
			'section_content',
			[
				'label' => esc_html__('Content', 'lovelove-core'),
				'default' => esc_html__('your content text', 'lovelove-core'),
				'placeholder' => esc_html__('Type your content here', 'lovelove-core'),
				'type' => Controls_Manager::TEXTAREA,
				'label_block' => true,
			]
		);
		$this->add_control(
			'portfolio_gallery',
			[
				'label' => esc_html__('Add Images', 'lovelove-core'),
				'type' => \Elementor\Controls_Manager::GALLERY,
				'default' => [],
			]
		);
		$repeater = new Repeater();
		$repeater->add_control(
			'feature_title',
			[
				'label' => esc_html__('Title Text', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__('Title Text', 'lovelove-core'),
				'placeholder' => esc_html__('Type title text here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'feature_content',
			[
				'label' => esc_html__('Content', 'lovelove-core'),
				'default' => esc_html__('your content text', 'lovelove-core'),
				'placeholder' => esc_html__('Type your content here', 'lovelove-core'),
				'type' => Controls_Manager::TEXTAREA,
				'label_block' => true,
			]
		);

		$this->add_control(
			'single_portfolio_groups',
			[
				'label' => esc_html__('Feature Icons', 'lovelove-core'),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'single_feature_title' => esc_html__('Feature', 'lovelove-core'),
					],

				],
				'fields' =>  $repeater->get_controls(),
				'title_field' => '{{{ single_feature_title }}}',
			]
		);
		$this->end_controls_section(); // end: Section

		// Title
		$this->start_controls_section(
			'single_service_section_title_style',
			[
				'label' => esc_html__('Title', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Typography', 'lovelove-core'),
				'name' => 'sasban_title_typography',
				'selector' => '{{WRAPPER}} .wpo-portfolio-single-section .portfolio-single-text h2',
			]
		);
		$this->add_control(
			'single_service_title_color',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-portfolio-single-section .portfolio-single-text h2' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'single_service_title_padding',
			[
				'label' => esc_html__('Title Padding', 'lovelove-core'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em'],
				'selectors' => [
					'{{WRAPPER}} .wpo-portfolio-single-section .portfolio-single-text h2' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section


		// Content
		$this->start_controls_section(
			'single_service_section_content_style',
			[
				'label' => esc_html__('Content', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Typography', 'lovelove-core'),
				'name' => 'single_service_content_typography',
				'selector' => '{{WRAPPER}} .wpo-portfolio-single-section .portfolio-single-text p',
			]
		);
		$this->add_control(
			'single_service_content_color',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-portfolio-single-section .portfolio-single-text p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'single_service_content_padding',
			[
				'label' => esc_html__('Title Padding', 'lovelove-core'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em'],
				'selectors' => [
					'{{WRAPPER}} .wpo-portfolio-single-section .portfolio-single-text p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section

		// List
		$this->start_controls_section(
			'single_service_section_list_style',
			[
				'label' => esc_html__('List Item', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Typography', 'lovelove-core'),
				'name' => 'single_service_list_typography',
				'selector' => '{{WRAPPER}} .wpo-portfolio-single-section .wpo-portfolio-single-content-des ul li span, .wpo-portfolio-single-section .wpo-portfolio-single-content-des ul li',
			]
		);
		$this->add_control(
			'single_service_list_color',
			[
				'label' => esc_html__('Title Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-portfolio-single-section .wpo-portfolio-single-content-des ul li' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'single_service_list_desc_color',
			[
				'label' => esc_html__('Content Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-portfolio-single-section .wpo-portfolio-single-content-des ul li span' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'single_service_list_padding',
			[
				'label' => esc_html__('Title Padding', 'lovelove-core'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em'],
				'selectors' => [
					'{{WRAPPER}} .wpo-portfolio-single-section .wpo-portfolio-single-content-des ul li' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section

	}

	/**
	 * Render ProjectItem widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 */
	protected function render()
	{
		$settings = $this->get_settings_for_display();
		$single_portfolio_groups = !empty($settings['single_portfolio_groups']) ? $settings['single_portfolio_groups'] : [];
		$section_title = !empty($settings['section_title']) ? $settings['section_title'] : '';
		$section_content = !empty($settings['section_content']) ? $settings['section_content'] : '';
		$portfolio_gallery = !empty($settings['portfolio_gallery']) ? $settings['portfolio_gallery'] : '';


		// Turn output buffer on
		ob_start(); ?>

		<div class="wpo-portfolio-single-section">
			<div class="container">
				<div class="portfolio-single-wrap">
					<div class="row">
						<div class="col-lg-7 col-12">
							<div class="portfolio-single-img-wrap">
								<?php
								// Group Param Output
								if (is_array($portfolio_gallery) && !empty($portfolio_gallery)) {
									foreach ($portfolio_gallery as $gallery_item) { ?>
										<div class="portfolio-single-img">
											<?php echo '<img src="' . esc_attr($gallery_item['url']) . '">'; ?>
										</div>
								<?php	}
								}
								?>
							</div>
						</div>
						<div class="col-lg-5 col-12">
							<div class="portfolio-single-sitebar">
								<div class="portfolio-single-text">
									<?php
									if ($section_title) {
										echo '<h2>' . esc_html($section_title) . '</h2>';
									}
									if ($section_content) {
										echo '<p>' . esc_html($section_content) . '</p>';
									}
									?>
									<div class="wpo-portfolio-single-content-des">
										<ul>
											<?php
											// Group Param Output
											if (is_array($single_portfolio_groups) && !empty($single_portfolio_groups)) {
												foreach ($single_portfolio_groups as $each_item) {

													$feature_title = !empty($each_item['feature_title']) ? $each_item['feature_title'] : '';
													$feature_content = !empty($each_item['feature_content']) ? $each_item['feature_content'] : '';

													if ($feature_title) {
														echo '<li>' . esc_html($feature_title) . '<span>' . esc_html($feature_content) . '</span></li>';
													}
												}
											}
											?>
										</ul>
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div> <!-- end container -->
		</div>
<?php
		// Return outbut buffer
		echo ob_get_clean();
	}
	/**
	 * Render ProjectItem widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 */

	//protected function _content_template(){}

}
Plugin::instance()->widgets_manager->register(new Lovelove_ProjectItem());
