<?php
/*
 * Elementor Lovelove Project Widget
 * Author & Copyright: wpoceans
*/

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Lovelove_Project extends Widget_Base
{

	/**
	 * Retrieve the widget name.
	 */
	public function get_name()
	{
		return 'wpo-lovelove_project';
	}

	/**
	 * Retrieve the widget title.
	 */
	public function get_title()
	{
		return esc_html__('Project', 'lovelove-core');
	}

	/**
	 * Retrieve the widget icon.
	 */
	public function get_icon()
	{
		return 'eicon-posts-masonry';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 */
	public function get_categories()
	{
		return ['wpoceans-category'];
	}

	/**
	 * Retrieve the list of scripts the Lovelove Project widget depended on.
	 * Used to set scripts dependencies required to run the widget.
	 */
	public function get_script_depends()
	{
		return ['wpo-lovelove_project'];
	}

	/**
	 * Register Lovelove Project widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 */
	protected function register_controls()
	{


		$posts = get_posts('post_type="project"&numberposts=-1');
		$PostID = array();
		if ($posts) {
			foreach ($posts as $post) {
				$PostID[$post->ID] = $post->ID;
			}
		} else {
			$PostID[__('No ID\'s found', 'lovelove')] = 0;
		}


		$this->start_controls_section(
			'section_project_listing',
			[
				'label' => esc_html__('Project Options', 'lovelove-core'),
			]
		);
		$this->add_control(
			'project_style',
			[
				'label' => esc_html__('Project Style', 'lovelove-core'),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'style-one' => esc_html__('Style One', 'lovelove-core'),
					'style-two' => esc_html__('Style Two', 'lovelove-core'),
				],
				'default' => 'style-one',
				'description' => esc_html__('Select your project style.', 'lovelove-core'),
			]
		);
		$this->add_control(
			'project_limit',
			[
				'label' => esc_html__('Project Limit', 'lovelove-core'),
				'type' => Controls_Manager::NUMBER,
				'min' => 1,
				'max' => 100,
				'step' => 1,
				'default' => 3,
				'description' => esc_html__('Enter the number of items to show.', 'lovelove-core'),
			]
		);
		$this->add_control(
			'project_order',
			[
				'label' => __('Order', 'lovelove-core'),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'ASC' => esc_html__('Asending', 'lovelove-core'),
					'DESC' => esc_html__('Desending', 'lovelove-core'),
				],
				'default' => 'DESC',
			]
		);
		$this->add_control(
			'project_orderby',
			[
				'label' => __('Order By', 'lovelove-core'),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'none' => esc_html__('None', 'lovelove-core'),
					'ID' => esc_html__('ID', 'lovelove-core'),
					'author' => esc_html__('Author', 'lovelove-core'),
					'title' => esc_html__('Title', 'lovelove-core'),
					'date' => esc_html__('Date', 'lovelove-core'),
				],
				'default' => 'date',
			]
		);
		$this->add_control(
			'project_show_category',
			[
				'label' => __('Certain Categories?', 'lovelove-core'),
				'type' => Controls_Manager::SELECT2,
				'default' => [],
				'options' => Controls_Helper_Output::get_terms_names('project_category'),
				'multiple' => true,
			]
		);
		$this->add_control(
			'project_show_id',
			[
				'label' => __('Certain ID\'s?', 'lovelove-core'),
				'type' => Controls_Manager::SELECT2,
				'default' => [],
				'options' => $PostID,
				'multiple' => true,
			]
		);
		$this->add_control(
			'project_more',
			[
				'label' => esc_html__('Plus', 'lovelove-core'),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__('Show', 'lovelove-core'),
				'label_off' => esc_html__('Hide', 'lovelove-core'),
				'return_value' => 'true',
				'default' => 'true',
			]
		);
		$this->end_controls_section(); // end: Section


		// Title
		$this->start_controls_section(
			'section_project_overly_style',
			[
				'label' => esc_html__('Overly', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'project_style' => array('style-two'),
				],
			]
		);
		$this->add_control(
			'overly_color',
			[
				'label' => esc_html__('Overly Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-portfolio-section-s4 .portfolio-grids .grid:hover .portfolio-content' => 'background-color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section

		// Title
		$this->start_controls_section(
			'section_title_style',
			[
				'label' => esc_html__('Title', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Typography', 'lovelove-core'),
				'name' => 'lovelove_title_typography',
				'selector' => '{{WRAPPER}} .lovelove-portfolio .grid .img-holder .portfolio-content h4',
			]
		);
		$this->add_control(
			'title_color',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lovelove-portfolio .grid .img-holder .portfolio-content h4 a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'title_padding',
			[
				'label' => esc_html__('Title Padding', 'lovelove-core'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em'],
				'selectors' => [
					'{{WRAPPER}} .lovelove-portfolio .grid .img-holder .portfolio-content h4' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section

		// Subtitle
		$this->start_controls_section(
			'section_subtitle_style',
			[
				'label' => esc_html__('Sub Title', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Typography', 'lovelove-core'),
				'name' => 'section_subtitle_typography',
				'selector' => '{{WRAPPER}} .lovelove-portfolio .grid .img-holder .portfolio-content span',
			]
		);
		$this->add_control(
			'subtitle_color',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lovelove-portfolio .grid .img-holder .portfolio-content span' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section

	}

	/**
	 * Render Project widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 */
	protected function render()
	{
		$settings = $this->get_settings_for_display();
		$project_style = !empty($settings['project_style']) ? $settings['project_style'] : '';
		$project_limit = !empty($settings['project_limit']) ? $settings['project_limit'] : '';
		$project_order = !empty($settings['project_order']) ? $settings['project_order'] : '';
		$project_orderby = !empty($settings['project_orderby']) ? $settings['project_orderby'] : '';
		$project_show_category = !empty($settings['project_show_category']) ? $settings['project_show_category'] : [];
		$project_show_id = !empty($settings['project_show_id']) ? $settings['project_show_id'] : [];
		$project_more = !empty($settings['project_more']) ? $settings['project_more'] : [];

		if ($project_style == 'style-one') {
			$project_wrap = 'wpo-portfolio-section';
		} else {
			$project_wrap = 'wpo-portfolio-section-s4';
		}

		// Turn output buffer on
		ob_start();

		// Pagination
		global $paged;
		if (get_query_var('paged'))
			$my_page = get_query_var('paged');
		else {
			if (get_query_var('page'))
				$my_page = get_query_var('page');
			else
				$my_page = 1;
			set_query_var('paged', $my_page);
			$paged = $my_page;
		}

		if ($project_show_id) {
			$project_show_id = json_encode($project_show_id);
			$project_show_id = str_replace(array('[', ']'), '', $project_show_id);
			$project_show_id = str_replace(array('"', '"'), '', $project_show_id);
			$project_show_id = explode(',', $project_show_id);
		} else {
			$project_show_id = '';
		}

		$args = array(
			// other query params here,
			'paged' => $my_page,
			'post_type' => 'project',
			'posts_per_page' => (int)$project_limit,
			'category_name' => implode(',', $project_show_category),
			'orderby' => $project_orderby,
			'order' => $project_order,
			'post__in' => $project_show_id,
		);

		$lovelove_project = new \WP_Query($args);
?>

		<div class="lovelove-portfolio <?php echo esc_attr($project_wrap); ?>">
			<div class="container">
				<div class="sortable-gallery">
					<div class="gallery-filters"></div>
					<div class="row">
						<div class="col-lg-12">
							<div class="portfolio-grids gallery-container clearfix">
								<?php
								if ($lovelove_project->have_posts()) : while ($lovelove_project->have_posts()) : $lovelove_project->the_post();

										$project_options = get_post_meta(get_the_ID(), 'project_options', true);

										$project_title = isset($project_options['project_title']) ? $project_options['project_title'] : '';
										$project_subtitle = isset($project_options['project_subtitle']) ? $project_options['project_subtitle'] : '';
										$project_image = isset($project_options['project_image']) ? $project_options['project_image'] : '';
										$project_image2 = isset($project_options['project_image2']) ? $project_options['project_image2'] : '';

										global $post;
										$image_url = wp_get_attachment_url($project_image);
										$image_alt = get_post_meta($project_image, '_wp_attachment_image_alt', true);

										$image2_url = wp_get_attachment_url($project_image2);
										$image2_alt = get_post_meta($project_image2, '_wp_attachment_image_alt', true);

										if ($project_style == 'style-one') {
											$image_src = $image_url;
											$image_alt = $image_alt;
										} else {
											$image_src = $image2_url;
											$image_alt = $image2_alt;
										}

								?>
										<div class="grid">
											<div class="img-holder">
												<?php if ($image_src) {
													echo '<img src="' . esc_url($image_src) . '" alt="' . esc_attr($image_alt) . '">';
												} ?>
												<div class="portfolio-content">
													<?php
													if ($project_title) {
														echo '<h4><a href="' . esc_url(get_permalink()) . '">' . esc_html($project_title) . '</a></h4>';
													}
													if ($project_subtitle) {
														echo '<span>' . esc_html($project_subtitle) . '</span>';
													}
													?>
												</div>
											</div>
										</div>
										<!--/item-->
								<?php
									endwhile;
								endif;
								wp_reset_postdata();
								?>
							</div>
						</div>
					</div>
				</div>
			</div> <!-- end container -->
		</div>
<?php
		// Return outbut buffer
		echo ob_get_clean();
	}
	/**
	 * Render Project widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 */

	//protected function _content_template(){}

}
Plugin::instance()->widgets_manager->register(new Lovelove_Project());
