<?php
/*
 * Elementor Lovelove Service Widget
 * Author & Copyright: wpoceans
*/

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Lovelove_Service extends Widget_Base
{

	/**
	 * Retrieve the widget name.
	 */
	public function get_name()
	{
		return 'wpo-lovelove_service';
	}

	/**
	 * Retrieve the widget title.
	 */
	public function get_title()
	{
		return esc_html__('Service', 'lovelove-core');
	}

	/**
	 * Retrieve the widget icon.
	 */
	public function get_icon()
	{
		return 'eicon-gallery-grid';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 */
	public function get_categories()
	{
		return ['wpoceans-category'];
	}

	/**
	 * Retrieve the list of scripts the Lovelove Service widget depended on.
	 * Used to set scripts dependencies required to run the widget.
	 */
	public function get_script_depends()
	{
		return ['wpo-lovelove_service'];
	}

	/**
	 * Register Lovelove Service widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 */
	protected function register_controls()
	{


		$posts = get_posts('post_type="service"&numberposts=-1');
		$PostID = array();
		if ($posts) {
			foreach ($posts as $post) {
				$PostID[$post->ID] = $post->ID;
			}
		} else {
			$PostID[__('No ID\'s found', 'lovelove')] = 0;
		}


		$this->start_controls_section(
			'section_service_listing',
			[
				'label' => esc_html__('Listing Options', 'lovelove-core'),
			]
		);
		$this->add_control(
			'service_style',
			[
				'label' => esc_html__('Service Style', 'lovelove-core'),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'style-one' => esc_html__('Style One', 'lovelove-core'),
					'style-two' => esc_html__('Style Two', 'lovelove-core'),
					'style-three' => esc_html__('Style Three', 'lovelove-core'),
				],
				'default' => 'style-one',
				'description' => esc_html__('Select your service style.', 'lovelove-core'),
			]
		);
		$this->add_control(
			'service_limit',
			[
				'label' => esc_html__('Service Limit', 'lovelove-core'),
				'type' => Controls_Manager::NUMBER,
				'min' => 1,
				'max' => 100,
				'step' => 1,
				'default' => 3,
				'description' => esc_html__('Enter the number of items to show.', 'lovelove-core'),
			]
		);
		$this->add_control(
			'service_order',
			[
				'label' => __('Order', 'lovelove-core'),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'ASC' => esc_html__('Asending', 'lovelove-core'),
					'DESC' => esc_html__('Desending', 'lovelove-core'),
				],
				'default' => 'DESC',
			]
		);
		$this->add_control(
			'service_orderby',
			[
				'label' => __('Order By', 'lovelove-core'),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'none' => esc_html__('None', 'lovelove-core'),
					'ID' => esc_html__('ID', 'lovelove-core'),
					'author' => esc_html__('Author', 'lovelove-core'),
					'title' => esc_html__('Title', 'lovelove-core'),
					'date' => esc_html__('Date', 'lovelove-core'),
				],
				'default' => 'date',
			]
		);
		$this->add_control(
			'service_show_category',
			[
				'label' => __('Certain Categories?', 'lovelove-core'),
				'type' => Controls_Manager::SELECT2,
				'default' => [],
				'options' => Controls_Helper_Output::get_terms_names('service_category'),
				'multiple' => true,
			]
		);
		$this->add_control(
			'service_show_id',
			[
				'label' => __('Certain ID\'s?', 'lovelove-core'),
				'type' => Controls_Manager::SELECT2,
				'default' => [],
				'options' => $PostID,
				'multiple' => true,
			]
		);
		$this->end_controls_section(); // end: Section

		// Service Item
		$this->start_controls_section(
			'section_service_item_style',
			[
				'label' => esc_html__('Service Box ', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'service_box_bg_color',
			[
				'label' => esc_html__('Background Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}}  .lovelove-services .wpo-Service-item' => 'background-color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section


		// Title
		$this->start_controls_section(
			'service_section_title_style',
			[
				'label' => esc_html__('Title', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Typography', 'lovelove-core'),
				'name' => 'service_lovelove_title_typography',
				'selector' => '{{WRAPPER}} .lovelove-services .wpo-Service-item .wpo-Service-text a',
			]
		);
		$this->add_control(
			'service_section_title_color',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lovelove-services .wpo-Service-item .wpo-Service-text a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'service_section_title_bg_color',
			[
				'label' => esc_html__('Background Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lovelove-services .wpo-Service-item .wpo-Service-text a' => 'background-color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'service_section_title_padding',
			[
				'label' => esc_html__('Title Padding', 'lovelove-core'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em'],
				'selectors' => [
					'{{WRAPPER}} .lovelove-services .wpo-Service-item .wpo-Service-text a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section


	}

	/**
	 * Render Service widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 */
	protected function render()
	{
		$settings = $this->get_settings_for_display();
		$service_style = !empty($settings['service_style']) ? $settings['service_style'] : '';
		$service_limit = !empty($settings['service_limit']) ? $settings['service_limit'] : '';
		$service_order = !empty($settings['service_order']) ? $settings['service_order'] : '';
		$service_orderby = !empty($settings['service_orderby']) ? $settings['service_orderby'] : '';
		$service_show_category = !empty($settings['service_show_category']) ? $settings['service_show_category'] : [];
		$service_show_id = !empty($settings['service_show_id']) ? $settings['service_show_id'] : [];

		if ($service_style == 'style-three') {
			$service_wrapper = 'wpo-Service-section-s3';
			$service_row = 'row';
			$service_container = 'container';
		} elseif ($service_style == 'style-two') {
			$service_wrapper = 'wpo-Service-section-s2';
			$service_row = 'service-slider owl-carousel';
			$service_container = 'container-fluid';
		} else {
			$service_wrapper = 'wpo-Service-section';
			$service_row = 'row';
			$service_container = 'container';
		}

		// Turn output buffer on
		ob_start();

		// Pagination
		global $paged;
		if (get_query_var('paged'))
			$my_page = get_query_var('paged');
		else {
			if (get_query_var('page'))
				$my_page = get_query_var('page');
			else
				$my_page = 1;
			set_query_var('paged', $my_page);
			$paged = $my_page;
		}

		if ($service_show_id) {
			$service_show_id = json_encode($service_show_id);
			$service_show_id = str_replace(array('[', ']'), '', $service_show_id);
			$service_show_id = str_replace(array('"', '"'), '', $service_show_id);
			$service_show_id = explode(',', $service_show_id);
		} else {
			$service_show_id = '';
		}

		$args = array(
			// other query params here,
			'paged' => $my_page,
			'post_type' => 'service',
			'posts_per_page' => (int)$service_limit,
			'category_name' => implode(',', $service_show_category),
			'orderby' => $service_orderby,
			'order' => $service_order,
			'post__in' => $service_show_id,
		);

		$lovelove_service = new \WP_Query($args); ?>
		<div class="lovelove-services <?php echo esc_attr($service_wrapper); ?>">
			<div class="<?php echo esc_attr($service_container); ?>">
				<div class="wpo-Service-wrap">
					<div class="<?php echo esc_attr($service_row); ?>">
						<?php
						$id = 0;
						if ($lovelove_service->have_posts()) : while ($lovelove_service->have_posts()) : $lovelove_service->the_post();
								$id++;
								$service_options = get_post_meta(get_the_ID(), 'service_options', true);
								$service_title = isset($service_options['service_title']) ? $service_options['service_title'] : '';
								$grid_image = isset($service_options['grid_image']) ? $service_options['grid_image'] : '';
								$grid_image2 = isset($service_options['grid_image2']) ? $service_options['grid_image2'] : '';
								$service_excerpt = isset($service_options['service_excerpt']) ? $service_options['service_excerpt'] : '';
								global $post;
								// service
								$bg_url = wp_get_attachment_url($grid_image);
								$bg_alt = get_post_meta($grid_image, '_wp_attachment_image_alt', true);

								$bg2_url = wp_get_attachment_url($grid_image2);
								$bg2_alt = get_post_meta($grid_image2, '_wp_attachment_image_alt', true);

								if ($service_style == 'style-three') {
									$image_bg = $bg2_url;
									$image_alt = $bg2_alt;
								} else {
									$image_bg = $bg_url;
									$image_alt = $bg_alt;
								}

								if ($service_style !== 'style-two') { ?>
									<div class="col-lg-3 col-md-6 col-sm-6 col-12">
									<?php } ?>

									<div class="wpo-Service-item">
										<div class="wpo-Service-img">
											<?php if ($image_bg) {
												echo '<img src="' . esc_url($image_bg) . '" alt="' . esc_attr($image_alt) . '">';
											} ?>
										</div>
										<div class="wpo-Service-text">
											<?php if ($id == 1 && $service_style == 'style-three') { ?>
												<h2><?php echo esc_html($service_title); ?></h2>
											<?php } else { ?>
												<a href="<?php echo esc_url(get_permalink()); ?>">
													<?php echo esc_html($service_title); ?>
												</a>
											<?php } ?>

										</div>
									</div>
									<?php if ($service_style !== 'style-two') { ?>
									</div>
						<?php }
								endwhile;
							endif;
							wp_reset_postdata();
						?>
					</div>
				</div>
			</div> <!-- end container -->
		</div>
<?php
		// Return outbut buffer
		echo ob_get_clean();
	}
	/**
	 * Render Service widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 */

	//protected function _content_template(){}

}
Plugin::instance()->widgets_manager->register(new Lovelove_Service());
