<?php
/*
 * Elementor Lovelove Slider Widget
 * Author & Copyright: wpoceans
*/

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Lovelove_Slider extends Widget_Base
{

	/**
	 * Retrieve the widget name.
	 */
	public function get_name()
	{
		return 'wpo-lovelove_slider';
	}

	/**
	 * Retrieve the widget title.
	 */
	public function get_title()
	{
		return esc_html__('Slider', 'lovelove-core');
	}

	/**
	 * Retrieve the widget icon.
	 */
	public function get_icon()
	{
		return 'eicon-slides';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 */
	public function get_categories()
	{
		return ['wpoceans-category'];
	}

	/**
	 * Retrieve the list of scripts the Lovelove Slider widget depended on.
	 * Used to set scripts dependencies required to run the widget.
	 */

	public function get_script_depends()
	{
		return ['wpo-lovelove_slider'];
	}


	/**
	 * Register Lovelove Slider widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 */
	protected function register_controls()
	{

		$this->start_controls_section(
			'section_slider',
			[
				'label' => __('Slider Options', 'lovelove-core'),
			]
		);
		$this->add_control(
			'slide_style',
			[
				'label' => esc_html__('Slide Layout', 'lovelove-core'),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'style-one' => esc_html__('Style One', 'lovelove-core'),
					'style-two' => esc_html__('Style Two', 'lovelove-core'),
					'style-three' => esc_html__('Style Three', 'lovelove-core'),
					'style-four' => esc_html__('Style Four', 'lovelove-core'),
					'style-five' => esc_html__('Style Five', 'lovelove-core'),
				],
				'default' => 'style-one',
				'description' => esc_html__('Select your slide style.', 'lovelove-core'),
			]
		);
		$this->add_control(
			'section_title',
			[
				'label' => esc_html__('Title Text', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'condition' => [
					'slide_style' => array('style-two', 'style-three'),
				],
				'default' => esc_html__('Title Text', 'lovelove-core'),
				'placeholder' => esc_html__('Type title text here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$this->add_control(
			'section_subtitle',
			[
				'label' => esc_html__('Sub Title Text', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'condition' => [
					'slide_style' => array('style-two', 'style-three'),
				],
				'default' => esc_html__('Sub Title Text', 'lovelove-core'),
				'placeholder' => esc_html__('Type subtitle text here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$this->add_control(
			'slider_shape',
			[
				'label' => esc_html__('Slider Shape', 'lovelove-core'),
				'type' => Controls_Manager::MEDIA,
				'condition' => [
					'slide_style' => array('style-three'),
				],
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);
		$this->add_control(
			'slider_shape2',
			[
				'label' => esc_html__('Slider Shape 2', 'lovelove-core'),
				'type' => Controls_Manager::MEDIA,
				'condition' => [
					'slide_style' => array('style-three'),
				],
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);
		$this->add_control(
			'countdown_date',
			[
				'label' => esc_html__('Countdown Date', 'lovelove-core'),
				'type' => Controls_Manager::DATE_TIME,
				'condition' => [
					'slide_style' => array('style-three'),
				],
				'default' => date("Y-m-d", strtotime("+ 1 day")),
				'description' => esc_html__('Set the due date and time', 'lovelove-core'),
			]
		);
		$this->add_control(
			'countdown_days',
			[
				'label' => esc_html__('Countdown Days', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'condition' => [
					'slide_style' => array('style-three'),
				],
				'default' => esc_html__('Days', 'lovelove-core'),
				'placeholder' => esc_html__('Type Days text here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$this->add_control(
			'countdown_hours',
			[
				'label' => esc_html__('Countdown Hours', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'condition' => [
					'slide_style' => array('style-three'),
				],
				'default' => esc_html__('Hours', 'lovelove-core'),
				'placeholder' => esc_html__('Type Hours text here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$this->add_control(
			'countdown_mins',
			[
				'label' => esc_html__('Countdown Mins', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'condition' => [
					'slide_style' => array('style-three'),
				],
				'default' => esc_html__('Mins', 'lovelove-core'),
				'placeholder' => esc_html__('Type Mins text here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$this->add_control(
			'countdown_secs',
			[
				'label' => esc_html__('Countdown Secs', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'condition' => [
					'slide_style' => array('style-three'),
				],
				'default' => esc_html__('Secs', 'lovelove-core'),
				'placeholder' => esc_html__('Type Secs text here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$this->add_control(
			'show_slide',
			[
				'label' => esc_html__('Show Slide', 'lovelove-core'),
				'type' => Controls_Manager::SWITCHER,
				'condition' => [
					'slide_style' => array('style-three'),
				],
				'label_on' => esc_html__('Show', 'lovelove-core'),
				'label_off' => esc_html__('Hide', 'lovelove-core'),
				'return_value' => 'true',
				'default' => 'true',
			]
		);
		$repeater = new Repeater();
		$repeater->add_control(
			'slider_style',
			[
				'label' => esc_html__('Slider Style', 'lovelove-core'),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'style-one' => esc_html__('Style One', 'lovelove-core'),
					'style-two' => esc_html__('Style Two', 'lovelove-core'),
					'style-three' => esc_html__('Style three', 'lovelove-core'),
					'style-four' => esc_html__('Style four', 'lovelove-core'),
					'style-five' => esc_html__('Style five', 'lovelove-core'),
				],
				'default' => 'style-one',
				'description' => esc_html__('Select your slide style.', 'lovelove-core'),
			]
		);
		$repeater->add_control(
			'slider_title',
			[
				'label' => esc_html__('Slider title', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
				'default' => 'We Fight For Your Justice As Like A Friend.',
				'placeholder' => esc_html__('Type slide title here', 'lovelove-core'),
			]
		);
		$repeater->add_control(
			'slider_content',
			[
				'label' => esc_html__('Slider content', 'lovelove-core'),
				'type' => Controls_Manager::TEXTAREA,
				'condition' => [
					'slider_style' => array('style-four', 'style-five'),
				],
				'label_block' => true,
				'default' => 'Slider Details content',
				'placeholder' => esc_html__('Type slide content here', 'lovelove-core'),
			]
		);
		$repeater->add_control(
			'btn_txt',
			[
				'label' => esc_html__('Button Text', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'condition' => [
					'slider_style' => array('style-four', 'style-five'),
				],
				'label_block' => true,
				'default' => 'Explore more',
				'placeholder' => esc_html__('Type your button text here', 'lovelove-core'),
			]
		);
		$repeater->add_control(
			'button_link',
			[
				'label' => esc_html__('Button Link', 'lovelove-core'),
				'type' => Controls_Manager::URL,
				'condition' => [
					'slider_style' => array('style-four', 'style-five'),
				],
				'placeholder' => __('https://your-link.com', 'lovelove-core'),
				'show_external' => true,
				'default' => [
					'url' => '#',
				],
			]
		);
		$repeater->add_control(
			'slider_image',
			[
				'label' => esc_html__('Slider Image', 'lovelove-core'),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);
		$repeater->add_control(
			'slider_shape',
			[
				'label' => esc_html__('Slider Shape', 'lovelove-core'),
				'type' => Controls_Manager::MEDIA,
				'condition' => [
					'slider_style' => array('style-four'),
				],
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);
		$repeater->add_control(
			'slider_shape2',
			[
				'label' => esc_html__('Slider Shape 2', 'lovelove-core'),
				'type' => Controls_Manager::MEDIA,
				'condition' => [
					'slider_style' => array('style-four'),
				],
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);
		$this->add_control(
			'swipeSliders_groups',
			[
				'label' => esc_html__('Slider Items', 'lovelove-core'),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'slider_title' => esc_html__('Item #1', 'lovelove-core'),
					],

				],
				'fields' =>  $repeater->get_controls(),
				'title_field' => '{{{ slider_title }}}',
			]
		);
		$this->end_controls_section(); // end: Section

		$this->start_controls_section(
			'section_carousel',
			[
				'label' => esc_html__('Carousel Options', 'lovelove-core'),
			]
		);
		$this->add_control(
			'carousel_nav',
			[
				'label' => esc_html__('Navigation', 'lovelove-core'),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__('Yes', 'lovelove-core'),
				'label_off' => esc_html__('No', 'lovelove-core'),
				'return_value' => 'true',
				'description' => esc_html__('If you want Carousel Navigation, enable it.', 'lovelove-core'),
			]
		);

		$this->end_controls_section(); // end: Section


		// Slide
		$this->start_controls_section(
			'section_slide_option_style',
			[
				'label' => esc_html__('Slide', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'slide_style' => array('style-two', 'style-three', 'style-four', 'style-five'),
				],
			]
		);
		$this->add_responsive_control(
			'slide_padding',
			[
				'label' => __('Content Padding', 'lovelove-core'),
				'type' => Controls_Manager::DIMENSIONS,
				'condition' => [
					'slide_style' => array('style-four', 'style-five'),
				],
				'size_units' => ['px', 'em'],
				'selectors' => [
					'{{WRAPPER}} .wpo-hero-slider .slide-inner .slide-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_responsive_control(
			'slide_height',
			[
				'label' => __('Height', 'lovelove-core'),
				'type' => Controls_Manager::SLIDER,
				'condition' => [
					'slide_style' => array('style-two', 'style-three', 'style-four', 'style-five'),
				],
				'size_units' => ['px', 'em'],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 500,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 900,
				],
				'selectors' => [
					'{{WRAPPER}} .wpo-hero-slider' => 'height: {{SIZE}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section


		// Title
		$this->start_controls_section(
			'section_title_style',
			[
				'label' => esc_html__('Title', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .lovelove-slider .wpo-hero-text h2, .wpo-hero-style-2 .wedding-announcement .couple-text h2, .wpo-wedding-date h2, .wpo-hero-slider-s3 .slide-inner .slide-content h2, .wpo-hero-slider-s4 .slide-inner .slide-content-wrap .slide-content h2',
			]
		);
		$this->add_control(
			'title_bg_color',
			[
				'label' => esc_html__('BG Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'slide_style' => array('style-five'),
				],
				'selectors' => [
					'{{WRAPPER}} .wpo-hero-slider-s4 .slide-inner .slide-content-wrap .slide-content' => 'background-color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'title_color',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lovelove-slider .wpo-hero-text h2, .wpo-hero-style-2 .wedding-announcement .couple-text h2, .wpo-wedding-date h2, .wpo-hero-slider-s3 .slide-inner .slide-content h2, .wpo-hero-slider-s4 .slide-inner .slide-content-wrap .slide-content h2' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_responsive_control(
			'title_padding',
			[
				'label' => esc_html__('Title Padding', 'lovelove-core'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em'],
				'selectors' => [
					'{{WRAPPER}} .lovelove-slider .wpo-hero-text h2, .wpo-hero-style-2 .wedding-announcement .couple-text h2, .wpo-wedding-date h2, .wpo-hero-slider-s3 .slide-inner .slide-content h2, .wpo-hero-slider-s4 .slide-inner .slide-content-wrap .slide-content h2' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section

		// Content
		$this->start_controls_section(
			'section_content_style',
			[
				'label' => esc_html__('Content', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'slide_style' => array('style-two', 'style-three', 'style-four', 'style-five'),
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'slider_content_typography',
				'selector' => '{{WRAPPER}} .wpo-hero-style-2 .wedding-announcement .couple-text p,.wpo-wedding-date p, .wpo-hero-slider-s3 .slide-inner .slide-content p, .wpo-hero-slider-s4 .slide-inner .slide-content-wrap .slide-content p',
			]
		);
		$this->add_control(
			'slider_content_color',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-hero-style-2 .wedding-announcement .couple-text p,.wpo-wedding-date p, .wpo-hero-slider-s3 .slide-inner .slide-content p, .wpo-hero-slider-s4 .slide-inner .slide-content-wrap .slide-content p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'content_padding',
			[
				'label' => esc_html__('Content Padding', 'lovelove-core'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em'],
				'selectors' => [
					'{{WRAPPER}} .wpo-hero-style-2 .wedding-announcement .couple-text p,.wpo-wedding-date p, .wpo-hero-slider-s3 .slide-inner .slide-content p, .wpo-hero-slider-s4 .slide-inner .slide-content-wrap .slide-content p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section


		// Navigation
		$this->start_controls_section(
			'section_navigation_style',
			[
				'label' => esc_html__('Navigation', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'slider_nav_color',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-hero-section .wpo-hero-items .owl-nav .owl-prev i:before, .wpo-hero-section .wpo-hero-items .owl-nav .owl-next i:before,.wpo-hero-slider .swiper-button-next:before, .wpo-hero-slider .swiper-container-horizontal > .swiper-pagination-bullets .swiper-pagination-bullet, .wpo-hero-slider .swiper-pagination .swiper-pagination-bullet.swiper-pagination-bullet-active:before' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'slider_nav_bg_color',
			[
				'label' => esc_html__('Background Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}}  .wpo-hero-section .wpo-hero-items .owl-nav .owl-prev, .wpo-hero-section .wpo-hero-items .owl-nav .owl-next' => 'background-color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section


		// Counter Title
		$this->start_controls_section(
			'counter_title_style',
			[
				'label' => esc_html__('Counter Title', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'slide_style' => array('style-three'),
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Typography', 'lovelove-core'),
				'name' => 'lovelove_counter_title_typography',
				'selector' => '{{WRAPPER}} .wpo-hero-style-3 .wpo-wedding-date #clock span, .wpo-wedding-date #clock span',
			]
		);
		$this->add_control(
			'counter_title',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-hero-style-3 .wpo-wedding-date #clock span, .wpo-wedding-date #clock span' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section

		// Counter Date
		$this->start_controls_section(
			'counter_date_style',
			[
				'label' => esc_html__('Counter Date', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'slide_style' => array('style-three'),
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Typography', 'lovelove-core'),
				'name' => 'lovelove_counter_date_typography',
				'selector' => '{{WRAPPER}} .wpo-wedding-date #clock .time',
			]
		);
		$this->add_control(
			'counter_date',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-wedding-date #clock .time' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section

		// Button Style
		$this->start_controls_section(
			'section_button_style',
			[
				'label' => esc_html__('Button', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'slide_style' => array('style-four', 'style-five'),
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'button_typography',
				'selector' => '{{WRAPPER}} .wpo-hero-slider .slide-btns .theme-btn',
			]
		);
		$this->add_responsive_control(
			'button_min_width',
			[
				'label' => esc_html__('Width', 'lovelove-core'),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 10,
						'max' => 500,
						'step' => 1,
					],
				],
				'size_units' => ['px'],
				'selectors' => [
					'{{WRAPPER}} .wpo-hero-slider .slide-btns .theme-btn' => 'min-width: {{SIZE}}{{UNIT}};',
				],
			]
		);
		$this->add_control(
			'button_padding',
			[
				'label' => __('Padding', 'lovelove-core'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em'],
				'selectors' => [
					'{{WRAPPER}} .wpo-hero-slider .slide-btns .theme-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_control(
			'button_border_radius',
			[
				'label' => __('Border Radius', 'lovelove-core'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors' => [
					'{{WRAPPER}} .wpo-hero-slider .slide-btns .theme-btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->start_controls_tabs('button_style');
		$this->start_controls_tab(
			'button_normal',
			[
				'label' => esc_html__('Normal', 'lovelove-core'),
			]
		);
		$this->add_control(
			'button_color',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-hero-slider .slide-btns .theme-btn' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'button_bg_color',
				'label' => esc_html__('Background', 'lovelove-core'),
				'description' => esc_html__('Button Color', 'lovelove-core'),
				'types' => ['gradient'],
				'selector' => '{{WRAPPER}} .wpo-hero-slider .slide-btns .theme-btn',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'button_border',
				'label' => esc_html__('Border', 'lovelove-core'),
				'selector' => '{{WRAPPER}} .wpo-hero-slider .slide-btns .theme-btn:after',
			]
		);
		$this->end_controls_tab();  // end:Normal tab

		$this->start_controls_tab(
			'button_hover',
			[
				'label' => esc_html__('Hover', 'lovelove-core'),
			]
		);
		$this->add_control(
			'button_hover_color',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-hero-slider .slide-btns .theme-btn:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'button_bg_hover_color',
				'label' => esc_html__('Hover Background', 'lovelove-core'),
				'description' => esc_html__('Hover Background Color', 'lovelove-core'),
				'types' => ['gradient'],
				'selector' => '{{WRAPPER}} .lovelove-hero .btns .theme-btn:hover',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'button_hover_border',
				'label' => esc_html__('Border', 'lovelove-core'),
				'selector' => '{{WRAPPER}} .wpo-hero-slider .slide-btns .theme-btn:hover',
			]
		);
		$this->end_controls_tab();  // end:Hover tab
		$this->end_controls_tabs(); // end tabs

		$this->end_controls_section(); // end: Section



	}

	/**
	 * Render Blog widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 */
	protected function render()
	{
		$settings = $this->get_settings_for_display();
		$slide_style = !empty($settings['slide_style']) ? $settings['slide_style'] : '';
		$show_slide  = (isset($settings['show_slide']) && ('true' == $settings['show_slide'])) ? true : false;
		// Carousel Options
		$swipeSliders_groups = !empty($settings['swipeSliders_groups']) ? $settings['swipeSliders_groups'] : [];
		$carousel_nav  = (isset($settings['carousel_nav']) && ('true' == $settings['carousel_nav'])) ? true : false;

		$section_subtitle = !empty($settings['section_subtitle']) ? $settings['section_subtitle'] : '';
		$section_title = !empty($settings['section_title']) ? $settings['section_title'] : '';

		$countdown_date = !empty($settings['countdown_date']) ? $settings['countdown_date'] : '';

		$countdown_days = !empty($settings['countdown_days']) ? $settings['countdown_days'] : '';
		$countdown_hours = !empty($settings['countdown_hours']) ? $settings['countdown_hours'] : '';
		$countdown_mins = !empty($settings['countdown_mins']) ? $settings['countdown_mins'] : '';
		$countdown_secs = !empty($settings['countdown_secs']) ? $settings['countdown_secs'] : '';

		$bg_shape = !empty($settings['slider_shape']['id']) ? $settings['slider_shape']['id'] : '';
		$bg_shape2 = !empty($settings['slider_shape2']['id']) ? $settings['slider_shape2']['id'] : '';

		$shape_url = wp_get_attachment_url($bg_shape);
		$shape2_url = wp_get_attachment_url($bg_shape2);

		$shape_alt = get_post_meta($bg_shape, '_wp_attachment_image_alt', true);
		$shape2_alt = get_post_meta($bg_shape2, '_wp_attachment_image_alt', true);

		if ($slide_style == 'style-five') {
			$slide_wrapper = 'wpo-hero-slider-s4';
		} else {
			$slide_wrapper = 'wpo-hero-slider-s3';
		}

		// Turn output buffer on
		ob_start();

		if ($slide_style == 'style-one') { ?>
			<div class="wpo-hero-section lovelove-slider">
				<div class="container-fluid">
					<div class="row">
						<div class="wpo-hero-items owl-carousel">
							<?php
							if (is_array($swipeSliders_groups) && !empty($swipeSliders_groups)) {
								foreach ($swipeSliders_groups as $each_item) {
									$bg_image = !empty($each_item['slider_image']['id']) ? $each_item['slider_image']['id'] : '';
									$image_url = wp_get_attachment_url($bg_image);
									$image_alt = get_post_meta($bg_image, '_wp_attachment_image_alt', true);
									$slider_title = !empty($each_item['slider_title']) ? $each_item['slider_title'] : '';

							?>
									<div class="wpo-hero-item">
										<div class="wpo-hero-img">
											<?php if ($image_url) {
												echo '<img src="' . esc_url($image_url) . '" alt="' . esc_attr($image_alt) . '">';
											} ?>
											<div class="wpo-hero-text">
												<?php if ($slider_title) {
													echo '<h2>' . esc_html($slider_title) . '</h2>';
												} ?>
											</div>
										</div>
									</div>
							<?php }
							} ?>
						</div>
					</div>
				</div>
			</div>
		<?php  } elseif ($slide_style == 'style-two') { ?>
			<div class="wpo-hero-slider wpo-hero-style-2">
				<div class="wedding-announcement">
					<div class="couple-text">
						<?php
						if ($section_title) {
							echo '<h2 class="wow slideInUp" data-wow-duration="1s">' . esc_html($section_title) . '</h2>';
						}
						if ($section_subtitle) {
							echo '<p class="wow slideInUp" data-wow-duration="1.8s">' . esc_html($section_subtitle) . '</p>';
						}
						?>
					</div>
				</div>
				<div class="swiper-container">
					<div class="swiper-wrapper">
						<?php
						if (is_array($swipeSliders_groups) && !empty($swipeSliders_groups)) {
							foreach ($swipeSliders_groups as $each_item) {
								$bg_image = !empty($each_item['slider_image']['id']) ? $each_item['slider_image']['id'] : '';
								$image_url = wp_get_attachment_url($bg_image);
								$image_alt = get_post_meta($bg_image, '_wp_attachment_image_alt', true);

						?>
								<div class="swiper-slide">
									<div class="slide-inner slide-bg-image" data-background="<?php echo esc_url($image_url); ?>">
									</div> <!-- end slide-inner -->
								</div> <!-- end swiper-slide -->
						<?php }
						} ?>
					</div>
					<!-- end swiper-wrapper -->
					<?php if ($carousel_nav) { ?>
						<!-- swipper controls -->
						<div class="swiper-pagination"></div>
					<?php } ?>
				</div>
			</div>
		<?php } elseif ($slide_style == 'style-three') { ?>

			<?php if ($show_slide) { ?>
				<div class="wpo-hero-slider wpo-hero-style-3">
					<div class="swiper-container">
						<div class="swiper-wrapper">
							<?php
							if (is_array($swipeSliders_groups) && !empty($swipeSliders_groups)) {
								foreach ($swipeSliders_groups as $each_item) {
									$bg_image = !empty($each_item['slider_image']['id']) ? $each_item['slider_image']['id'] : '';
									$image_url = wp_get_attachment_url($bg_image);
									$image_alt = get_post_meta($bg_image, '_wp_attachment_image_alt', true);

							?>
									<div class="swiper-slide">
										<div class="slide-inner slide-bg-image" data-background="<?php echo esc_url($image_url); ?>">
										</div> <!-- end slide-inner -->
									</div> <!-- end swiper-slide -->
							<?php }
							} ?>
						</div>
						<!-- end swiper-wrapper -->
						<!-- swipper controls -->
						<div class="swiper-pagination"></div>
					</div>
				</div>
			<?php } ?>

			<div class="wpo-wedding-date">
				<div class="container">
					<?php if ($section_title) { ?>
						<h2>
							<span class="shape-1">
								<?php if ($shape_url) {
									echo '<img src="' . esc_url($shape_url) . '" alt="' . esc_attr($shape_alt) . '">';
								} ?>
							</span>
							<?php echo esc_html($section_title); ?>
							<span class="shape-2">
								<?php if ($shape2_url) {
									echo '<img src="' . esc_url($shape2_url) . '" alt="' . esc_attr($shape2_alt) . '">';
								} ?>
							</span>
						</h2>
					<?php }
					if ($section_subtitle) {
						echo '<p class="clock-desc">' . esc_html($section_subtitle) . '</p>';
					} ?>
					<div class="row">
						<div class="col col-xs-12">
							<div class="clock-grids">
								<div id="clock" data-date="<?php echo esc_attr($countdown_date); ?>"></div>
							</div>
						</div>
					</div>
				</div> <!-- end container -->
			</div>
			<script>
				jQuery(document).ready(function() {
					/*------------------------------------------
            = COUNTDOWN CLOCK
        -------------------------------------------*/
					if (jQuery("#clock").length) {
						var weddingDate = jQuery('#clock').data('date');
						jQuery('#clock').countdown(weddingDate, function(event) {
							var $this = jQuery(this).html(event.strftime('' +
								'<div class="box"><div><div class="time">%D</div> <span><?php echo esc_html($countdown_days); ?></span></div></div>' +
								'<div class="box"><div><div class="time">%H</div> <span><?php echo esc_html($countdown_hours); ?></span></div></div>' +
								'<div class="box"><div><div class="time">%M</div> <span><?php echo esc_html($countdown_mins); ?></span> </div></div>' +
								'<div class="box"><div><div class="time">%S</div> <span><?php echo esc_html($countdown_secs); ?></span> </div></div>'));
						});
					}

				});
			</script>
		<?php } else { ?>
			<div class="wpo-hero-slider <?php echo esc_attr($slide_wrapper); ?>">
				<div class="swiper-container">
					<div class="swiper-wrapper">
						<?php
						if (is_array($swipeSliders_groups) && !empty($swipeSliders_groups)) {
							foreach ($swipeSliders_groups as $each_item) {
								$bg_image = !empty($each_item['slider_image']['id']) ? $each_item['slider_image']['id'] : '';

								$image_url = wp_get_attachment_url($bg_image);

								$bg_shape = !empty($each_item['slider_shape']['id']) ? $each_item['slider_shape']['id'] : '';
								$bg_shape2 = !empty($each_item['slider_shape2']['id']) ? $each_item['slider_shape2']['id'] : '';

								$shape_url = wp_get_attachment_url($bg_shape);
								$shape2_url = wp_get_attachment_url($bg_shape2);

								$shape_alt = get_post_meta($bg_shape, '_wp_attachment_image_alt', true);
								$shape2_alt = get_post_meta($bg_shape2, '_wp_attachment_image_alt', true);

								$slider_title = !empty($each_item['slider_title']) ? $each_item['slider_title'] : '';
								$slider_content = !empty($each_item['slider_content']) ? $each_item['slider_content'] : '';

								$button_text = !empty($each_item['btn_txt']) ? $each_item['btn_txt'] : '';
								$button_link = !empty($each_item['button_link']['url']) ? $each_item['button_link']['url'] : '';
								$button_link_external = !empty($each_item['button_link']['is_external']) ? 'target="_blank"' : '';
								$button_link_nofollow = !empty($each_item['button_link']['nofollow']) ? 'rel="nofollow"' : '';
								$button_link_attr = !empty($button_link) ?  $button_link_external . ' ' . $button_link_nofollow : '';

								$button_one = $button_link ? '<a href="' . esc_url($button_link) . '" ' . $button_link_attr . ' class="theme-btn" >' . $button_text . '</a>' : '';

								$button_actual = ($button_one) ? '<div data-swiper-parallax="500" class="slide-btns">' . $button_one . '</div>' : '';
						?>
								<div class="swiper-slide">
									<div class="slide-inner slide-bg-image" data-background="<?php echo esc_url($image_url); ?>">
										<div class="container-fluid">
											<div class="slide-content-wrap">
												<div class="shape-1">
													<?php if ($shape_url) {
														echo '<img src="' . esc_url($shape_url) . '" alt="' . esc_attr($shape_alt) . '">';
													} ?>
												</div>
												<div class="slide-content">

													<div data-swiper-parallax="300" class="slide-title">
														<?php if ($slider_title) {
															echo '<h2>' . esc_html($slider_title) . '</h2>';
														} ?>
													</div>

													<div data-swiper-parallax="400" class="slide-text">
														<?php if ($slider_content) {
															echo '<p>' . esc_html($slider_content) . '</p>';
														} ?>
													</div>

													<div class="clearfix"></div>

													<?php echo $button_actual; ?>
												</div>
												<div class="shape-2">
													<?php if ($shape2_url) {
														echo '<img src="' . esc_url($shape2_url) . '" alt="' . esc_attr($shape2_alt) . '">';
													} ?>
												</div>
											</div>
										</div>
									</div> <!-- end slide-inner -->
								</div> <!-- end swiper-slide -->
						<?php }
						} ?>
					</div>
					<!-- end swiper-wrapper -->
					<?php if ($carousel_nav) { ?>
						<!-- swipper controls -->
						<div class="swiper-pagination"></div>
					<?php } ?>
				</div>
			</div>
<?php }
		// Return outbut buffer
		echo ob_get_clean();
	}

	/**
	 * Render Blog widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 */

	//protected function _content_template(){}

}
Plugin::instance()->widgets_manager->register(new Lovelove_Slider());
