<?php
/*
 * Elementor Lovelove Story Widget
 * Author & Copyright: wpoceans
*/

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Lovelove_Story extends Widget_Base
{

	/**
	 * Retrieve the widget name.
	 */
	public function get_name()
	{
		return 'wpo-lovelove_story';
	}

	/**
	 * Retrieve the widget title.
	 */
	public function get_title()
	{
		return esc_html__('Story', 'lovelove-core');
	}

	/**
	 * Retrieve the widget icon.
	 */
	public function get_icon()
	{
		return 'eicon-time-line';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 */
	public function get_categories()
	{
		return ['wpoceans-category'];
	}

	/**
	 * Retrieve the list of scripts the Lovelove Story widget depended on.
	 * Used to set scripts dependencies required to run the widget.
	 */
	public function get_script_depends()
	{
		return ['wpo-lovelove_story'];
	}

	/**
	 * Register Lovelove Story widget controls.
	 * Adds different input fields to allow the user to change and customize the widget each_item.
	 */
	protected function register_controls()
	{

		$this->start_controls_section(
			'story_section',
			[
				'label' => esc_html__('Story Options', 'lovelove-core'),
			]
		);
		$this->add_control(
			'story_style',
			[
				'label' => esc_html__('Story Style', 'lovelove-core'),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'style-one' => esc_html__('Style One', 'lovelove-core'),
					'style-two' => esc_html__('Style Two', 'lovelove-core'),
					'style-three' => esc_html__('Style Three', 'lovelove-core'),
					'style-four' => esc_html__('Style Four', 'lovelove-core'),
				],
				'default' => 'style-one',
				'description' => esc_html__('Select your coundown style.', 'lovelove-core'),
			]
		);
		$repeater = new Repeater();
		$repeater->add_control(
			'story_title',
			[
				'label' => esc_html__('Title Text', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__('Our First Meet', 'lovelove-core'),
				'placeholder' => esc_html__('Type title text here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'story_date',
			[
				'label' => esc_html__('Story Date', 'lovelove-core'),
				'type' => Controls_Manager::DATE_TIME,
				'default' => esc_html__('Story Date', 'lovelove-core'),
				'placeholder' => esc_html__('Story Date here', 'lovelove-core'),
				'label_block' => true,
				'picker_options' => [
					'enableTime' => false,
					'dateFormat' => 'd/M/Y'
				]
			]
		);
		$repeater->add_control(
			'story_content',
			[
				'label' => esc_html__('Content Text', 'lovelove-core'),
				'type' => Controls_Manager::TEXTAREA,
				'default' => esc_html__('Content Text', 'lovelove-core'),
				'placeholder' => esc_html__('Type content text here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'story_image',
			[
				'label' => esc_html__('Story Image', 'lovelove-core'),
				'type' => Controls_Manager::MEDIA,
				'frontend_available' => true,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'description' => esc_html__('Set Story image here.', 'lovelove-core'),
			]
		);
		$repeater->add_control(
			'story_shape',
			[
				'label' => esc_html__('Story Image 2', 'lovelove-core'),
				'type' => Controls_Manager::MEDIA,
				'frontend_available' => true,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'description' => esc_html__('Set Story image here.', 'lovelove-core'),
			]
		);
		$this->add_control(
			'story_items_groups',
			[
				'label' => esc_html__('Story Item', 'lovelove-core'),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'story_title' => esc_html__('Story', 'lovelove-core'),
					],

				],
				'fields' =>  $repeater->get_controls(),
				'title_field' => '{{{ story_title }}}',
			]
		);
		$this->end_controls_section(); // end: Section


		// Story
		$this->start_controls_section(
			'section_story_style',
			[
				'label' => esc_html__('Story', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'story_shape_color',
			[
				'label' => esc_html__('BG Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'story_style' => array('style-four'),
				],
				'selectors' => [
					'{{WRAPPER}} .wpo-story-section-s4 .wpo-story-wrap .wpo-story-item .wpo-story-content-wrap .wpo-story-content-img:before' => 'background-color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'story_border_color',
			[
				'label' => esc_html__('Border Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-story-section .wpo-story-item .wpo-story-content, .wpo-story-section .wpo-story-item .wpo-story-content .wpo-story-content-inner:before, .wpo-story-section-s2 .wpo-story-item .wpo-story-content, .wpo-story-section-s2 .wpo-story-item .wpo-story-content .wpo-story-content-inner:before, .wpo-story-section-s3 .wpo-story-wrap .wpo-story-item .wpo-story-img-wrap::before, .wpo-story-section-s4 .wpo-story-wrap .wpo-story-item .wpo-story-content-wrap .wpo-story-content' => 'border-color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section



		// Title
		$this->start_controls_section(
			'section_title_style',
			[
				'label' => esc_html__('Title', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Typography', 'lovelove-core'),
				'name' => 'lovelove_title_typography',
				'selector' => '{{WRAPPER}} .story-section .wpo-story-item .wpo-story-content .wpo-story-content-inner h2',
			]
		);
		$this->add_control(
			'title_color',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .story-section .wpo-story-item .wpo-story-content .wpo-story-content-inner h2' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'title_padding',
			[
				'label' => __('Title Padding', 'lovelove-core'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em'],
				'selectors' => [
					'{{WRAPPER}} .story-section .wpo-story-item .wpo-story-content .wpo-story-content-inner h2' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section

		// Date
		$this->start_controls_section(
			'section_date_style',
			[
				'label' => esc_html__('Date', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Typography', 'lovelove-core'),
				'name' => 'lovelove_date_typography',
				'selector' => '{{WRAPPER}} .story-section .wpo-story-item .wpo-story-content .wpo-story-content-inner span',
			]
		);
		$this->add_control(
			'date_color',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .story-section .wpo-story-item .wpo-story-content .wpo-story-content-inner span' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'date_padding',
			[
				'label' => esc_html__('Title Padding', 'lovelove-core'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em'],
				'selectors' => [
					'{{WRAPPER}} .story-section .wpo-story-item .wpo-story-content .wpo-story-content-inner span' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section


		// Story Content
		$this->start_controls_section(
			'story_content_style',
			[
				'label' => esc_html__('Content', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Typography', 'lovelove-core'),
				'name' => 'lovelove_story_content_typography',
				'selector' => '{{WRAPPER}} .story-section .wpo-story-item .wpo-story-content .wpo-story-content-inner p',
			]
		);
		$this->add_control(
			'story_content',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .story-section .wpo-story-item .wpo-story-content .wpo-story-content-inner p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'story_content_padding',
			[
				'label' => esc_html__('Number Padding', 'lovelove-core'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em'],
				'selectors' => [
					'{{WRAPPER}} .story-section .wpo-story-item .wpo-story-content .wpo-story-content-inner p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section



	}

	/**
	 * Render Story widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 */
	protected function render()
	{
		$settings = $this->get_settings_for_display();
		$story_style = !empty($settings['story_style']) ? $settings['story_style'] : '';
		$story_items_groups = !empty($settings['story_items_groups']) ? $settings['story_items_groups'] : '';

		if ($story_style == 'style-one') {
			$story_wrap = 'wpo-story-section';
		} elseif ($story_style == 'style-two') {
			$story_wrap = 'wpo-story-section-s2';
		} elseif ($story_style == 'style-three') {
			$story_wrap = 'wpo-story-section-s3';
		} else {
			$story_wrap = 'wpo-story-section-s4';
		}

		ob_start();
?>
		<div class="story-section <?php echo esc_attr($story_wrap); ?>">
			<div class="container-fluid">
				<div class="wpo-story-wrap">
					<?php 	// Group Param Output
					if (is_array($story_items_groups) && !empty($story_items_groups)) {
						foreach ($story_items_groups as $each_item) {
							$story_title = !empty($each_item['story_title']) ? $each_item['story_title'] : '';
							$story_content = !empty($each_item['story_content']) ? $each_item['story_content'] : '';
							$story_date = !empty($each_item['story_date']) ? $each_item['story_date'] : '';

							$bg_image = !empty($each_item['story_image']['id']) ? $each_item['story_image']['id'] : '';
							$story_image = !empty($each_item['story_shape']['id']) ? $each_item['story_shape']['id'] : '';
							$image_url = wp_get_attachment_url($bg_image);
							$image_alt = get_post_meta($bg_image, '_wp_attachment_image_alt', true);

							$story_url = wp_get_attachment_url($story_image);
							$story_alt = get_post_meta($story_image, '_wp_attachment_image_alt', true);

					?>

							<?php if ($story_style == 'style-four') { ?>
								<div class="wpo-story-item">
									<div class="wpo-story-content-wrap">
										<div class="wpo-story-content-img">
											<?php if ($image_url) {
												echo '<img src="' . esc_url($image_url) . '" alt="' . esc_attr($image_alt) . '">';
											}  ?>
										</div>
										<div class="wpo-story-content">
											<div class="wpo-story-content-inner">
												<?php
												if ($story_title) {
													echo '<h2>' . esc_html($story_title) . '</h2>';
												}
												if ($story_date) {
													echo '<span class="date">' . esc_html($story_date) . '</span>';
												}
												if ($story_content) {
													echo '<p>' . esc_html($story_content) . '</p>';
												}
												?>
											</div>
										</div>
									</div>
									<div class="wpo-story-img-wrap">
										<div class="wpo-story-img">
											<?php if ($story_url) {
												echo '<img src="' . esc_url($story_url) . '" alt="' . esc_attr($story_alt) . '">';
											}  ?>
										</div>
									</div>
								</div>
							<?php } else { ?>
								<div class="wpo-story-item">
									<div class="wpo-story-img-wrap">
										<div class="wpo-story-img">
											<?php if ($image_url) {
												echo '<img src="' . esc_url($image_url) . '" alt="' . esc_attr($image_alt) . '">';
											}  ?>
										</div>
										<?php if ($story_style == 'style-one') { ?>
											<div class="wpo-img-shape">
												<?php if ($story_url) {
													echo '<img src="' . esc_url($story_url) . '" alt="' . esc_attr($story_alt) . '">';
												}  ?>
											</div>
										<?php } ?>
									</div>
									<div class="wpo-story-content">
										<div class="wpo-story-content-inner">
											<?php
											if ($story_title) {
												echo '<h2>' . esc_html($story_title) . '</h2>';
											}
											if ($story_date) {
												echo '<span class="date">' . esc_html($story_date) . '</span>';
											}
											if ($story_content) {
												echo '<p>' . esc_html($story_content) . '</p>';
											}
											?>
										</div>
									</div>
								</div>
							<?php } ?>

					<?php }
					} ?>
				</div>
			</div> <!-- end container -->
		</div>
<?php
		// Return outbut buffer
		echo ob_get_clean();
	}
	/**
	 * Render Story widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 */

	//protected function _content_template(){}

}
Plugin::instance()->widgets_manager->register(new Lovelove_Story());
