<?php
/*
 * Elementor Lovelove Testimonial Widget
 * Author & Copyright: wpoceans
*/

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Lovelove_Testimonial extends Widget_Base
{

	/**
	 * Retrieve the widget name.
	 */
	public function get_name()
	{
		return 'wpo-lovelove_testimonial';
	}

	/**
	 * Retrieve the widget title.
	 */
	public function get_title()
	{
		return esc_html__('Testimonial', 'lovelove-core');
	}

	/**
	 * Retrieve the widget icon.
	 */
	public function get_icon()
	{
		return 'eicon-testimonial-carousel';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 */
	public function get_categories()
	{
		return ['wpoceans-category'];
	}

	/**
	 * Retrieve the list of scripts the Lovelove Testimonial widget depended on.
	 * Used to set scripts dependencies required to run the widget.
	 */
	public function get_script_depends()
	{
		return ['wpo-lovelove_testimonial'];
	}

	/**
	 * Register Lovelove Testimonial widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 */
	protected function register_controls()
	{

		$this->start_controls_section(
			'section_testimonial',
			[
				'label' => esc_html__('Testimonial Options', 'lovelove-core'),
			]
		);
		$repeater = new Repeater();
		$repeater->add_control(
			'testimonial_title',
			[
				'label' => esc_html__('Testimonial Title Text', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__('Title Text', 'lovelove-core'),
				'placeholder' => esc_html__('Type title text here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'testimonial_subtitle',
			[
				'label' => esc_html__('Testimonial Sub Title', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__('Testimonial Sub Title', 'lovelove-core'),
				'placeholder' => esc_html__('Type testimonial Sub title here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'testimonial_content',
			[
				'label' => esc_html__('Testimonial Content', 'lovelove-core'),
				'type' => Controls_Manager::TEXTAREA,
				'default' => esc_html__('Testimonial Content', 'lovelove-core'),
				'placeholder' => esc_html__('Type testimonial Content here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'bg_image',
			[
				'label' => esc_html__('Testimonial Image', 'lovelove-core'),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],

			]
		);
		$this->add_control(
			'testimonialItems_groups',
			[
				'label' => esc_html__('Testimonial Items', 'lovelove-core'),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'testimonial_title' => esc_html__('Testimonial', 'lovelove-core'),
					],

				],
				'fields' =>  $repeater->get_controls(),
				'title_field' => '{{{ testimonial_title }}}',
			]
		);
		$this->end_controls_section(); // end: Section


		// Testimonial Title Style 
		$this->start_controls_section(
			'testimonials_section_title_style',
			[
				'label' => esc_html__('Title', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Typography', 'lovelove-core'),
				'name' => 'testimonials_lovelove_title_typography',
				'selector' => '{{WRAPPER}} .wpo-testimonial-section .wpo-testimonial-items .wpo-testimonial-text-btm h5',
			]
		);
		$this->add_control(
			'testimonials_title_color',
			[
				'label' => esc_html__('Name Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-testimonial-section .wpo-testimonial-items .wpo-testimonial-text-btm h5' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section

		// Testimonial Title Style 
		$this->start_controls_section(
			'testimonials_section_subtitle_style',
			[
				'label' => esc_html__('Sub Title', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Typography', 'lovelove-core'),
				'name' => 'testimonials_lovelove_subtitle_typography',
				'selector' => '{{WRAPPER}} .wpo-testimonial-section .wpo-testimonial-items .wpo-testimonial-text-btm span',
			]
		);
		$this->add_control(
			'testimonials_subtitle_color',
			[
				'label' => esc_html__('Subtitle Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-testimonial-section .wpo-testimonial-items .wpo-testimonial-text-btm span' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section

		// Testimonial Content Style 
		$this->start_controls_section(
			'testimonials_section_content_style',
			[
				'label' => esc_html__('Content', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Typography', 'lovelove-core'),
				'name' => 'testimonials_lovelove_section_content_typography',
				'selector' => '{{WRAPPER}} .wpo-testimonial-section .wpo-testimonial-items p',
			]
		);
		$this->add_control(
			'testimonials_section_content_color',
			[
				'label' => esc_html__('Title Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-testimonial-section .wpo-testimonial-items p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section

		// Dot Color
		$this->start_controls_section(
			'section_dot_style',
			[
				'label' => esc_html__('Dot', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'dot_bg_color',
			[
				'label' => esc_html__('Background Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-testimonial-section .slick-dots li button:before' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'dot_active_color',
			[
				'label' => esc_html__('Active Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-testimonial-section .slick-dots li.slick-active button:before' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section

		// Quote Color
		$this->start_controls_section(
			'section_quote_style',
			[
				'label' => esc_html__('Quote', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'quote_color',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-testimonial-section .wpo-testimonial-items i:before' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'quote_line_color',
			[
				'label' => esc_html__('Line Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-testimonial-section .wpo-testimonial-items:before' => 'border-color: {{VALUE}};',
					'{{WRAPPER}} .wpo-testimonial-section .wpo-testimonial-items:after' => 'background-color: {{VALUE}};'
				],
			]
		);
		$this->end_controls_section(); // end: Section

	}

	/**
	 * Render Testimonial widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 */
	protected function render()
	{
		$settings = $this->get_settings_for_display();
		$testimonialItems_groups = !empty($settings['testimonialItems_groups']) ? $settings['testimonialItems_groups'] : [];

		// Turn output buffer on
		ob_start(); ?>

		<div class="wpo-testimonial-section">
			<div class="container">
				<div class="wpo-testimonial-wrap">
					<div class="row align-items-center">
						<div class="col col-lg-7">
							<div class="slider-for">
								<?php 	// Group Param Output
								if (is_array($testimonialItems_groups) && !empty($testimonialItems_groups)) {
									foreach ($testimonialItems_groups as $each_items) {

										$bg_image = !empty($each_items['bg_image']['id']) ? $each_items['bg_image']['id'] : '';
										$image_url = wp_get_attachment_url($bg_image);
										$image_alt = get_post_meta($bg_image, '_wp_attachment_image_alt', true);

								?>
										<div class="testimonial-img">
											<?php if ($image_url) {
												echo '<img src="' . esc_url($image_url) . '" alt="' . esc_attr($image_alt) . '">';
											} ?>
										</div>
								<?php }
								} ?>
							</div>
						</div>
						<div class="col col-lg-5">
							<div class="wpo-testimonial-items">
								<div class="slider-nav">
									<?php 	// Group Param Output
									if (is_array($testimonialItems_groups) && !empty($testimonialItems_groups)) {
										foreach ($testimonialItems_groups as $each_items) {

											$testimonial_title = !empty($each_items['testimonial_title']) ? $each_items['testimonial_title'] : '';
											$testimonial_subtitle = !empty($each_items['testimonial_subtitle']) ? $each_items['testimonial_subtitle'] : '';
											$testimonial_content = !empty($each_items['testimonial_content']) ? $each_items['testimonial_content'] : '';
									?>
											<div class="wpo-testimonial-item">
												<div class="wpo-testimonial-text">
													<i class="fi flaticon-quotation"></i>
													<?php
													if ($testimonial_content) {
														echo '<p>' . esc_html($testimonial_content) . '</p>';
													}
													?>
													<div class="wpo-testimonial-text-btm">
														<?php
														if ($testimonial_title) {
															echo '<h5>' . esc_html($testimonial_title) . '</h5>';
														}
														if ($testimonial_subtitle) {
															echo '<span>' . esc_html($testimonial_subtitle) . '</span>';
														}
														?>
													</div>
												</div>
											</div>
									<?php }
									} ?>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
<?php
		// Return outbut buffer
		echo ob_get_clean();
	}
	/**
	 * Render Testimonial widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 */

	//protected function _content_template(){}

}
Plugin::instance()->widgets_manager->register(new Lovelove_Testimonial());
