<?php
/*
 * Elementor Lovelove CTA Widget
 * Author & Copyright: wpoceans
*/

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Lovelove_Video_CTA extends Widget_Base
{

	/**
	 * Retrieve the widget name.
	 */
	public function get_name()
	{
		return 'wpo-lovelove_videocta';
	}

	/**
	 * Retrieve the widget title.
	 */
	public function get_title()
	{
		return esc_html__('Video CTA', 'lovelove-core');
	}

	/**
	 * Retrieve the widget icon.
	 */
	public function get_icon()
	{
		return 'eicon-video-playlist';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 */
	public function get_categories()
	{
		return ['wpoceans-category'];
	}

	/**
	 * Retrieve the list of scripts the Lovelove CTA widget depended on.
	 * Used to set scripts dependencies required to run the widget.
	 */
	/*
	public function get_script_depends() {
		return ['wpo-lovelove_videocta'];
	}
	*/

	/**
	 * Register Lovelove CTA widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 */
	protected function register_controls()
	{

		$this->start_controls_section(
			'section_CTA',
			[
				'label' => esc_html__('CTA Options', 'lovelove-core'),
			]
		);
		$this->add_control(
			'videocta_style',
			[
				'label' => esc_html__('Video CTA Style', 'finco-core'),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'style-one' => esc_html__('Style One', 'finco-core'),
					'style-two' => esc_html__('Style Two', 'finco-core'),
				],
				'default' => 'style-one',
				'description' => esc_html__('Select your Video CTA style.', 'finco-core'),
			]
		);
		$this->add_control(
			'videocta_bg',
			[
				'label' => esc_html__('CTA BG', 'lovelove-core'),
				'type' => Controls_Manager::MEDIA,
				'frontend_available' => true,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'description' => esc_html__('Set your image.', 'lovelove-core'),
			]
		);
		$this->add_control(
			'video_link',
			[
				'label' => esc_html__('Video Link', 'lovelove-core'),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__('#', 'lovelove-core'),
				'placeholder' => esc_html__('Type video link here', 'lovelove-core'),
				'label_block' => true,
			]
		);
		$this->end_controls_section(); // end: Section

		// Section
		$this->start_controls_section(
			'section_videocta_style',
			[
				'label' => esc_html__('Section', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'videocta_bg_color',
			[
				'label' => esc_html__('BG Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lovelove-video-cta .video-wrap' => 'background-color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'videocta_bg_overly_color',
			[
				'label' => esc_html__('Overly Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .wpo-video-section .video-wrap:before' => 'background: {{VALUE}};',
				],
			]
		);
		$this->add_responsive_control(
			'videocta_section_padding',
			[
				'label' => esc_html__('Section Padding', 'lovelove-core'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors' => [
					'{{WRAPPER}} .lovelove-video-cta .video-wrap' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section

		// Video Icon
		$this->start_controls_section(
			'section_video_icon_style',
			[
				'label' => esc_html__('Video', 'lovelove-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Typography', 'lovelove-core'),
				'name' => 'section_video_icon_typography',
				'selector' => '{{WRAPPER}} .lovelove-video-cta .video-wrap i:before',
			]
		);
		$this->add_control(
			'icon_color',
			[
				'label' => esc_html__('Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lovelove-video-cta .video-wrap i:before' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'icon_bg_color',
			[
				'label' => esc_html__('BG Color', 'lovelove-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lovelove-video-cta .video-wrap a' => 'background-color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section(); // end: Section

	}

	/**
	 * Render CTA widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 */
	protected function render()
	{
		$settings = $this->get_settings_for_display();
		$videocta_style = !empty($settings['videocta_style']) ? $settings['videocta_style'] : '';
		$video_link = !empty($settings['video_link']) ? $settings['video_link'] : '';
		$bg_image = !empty($settings['videocta_bg']['id']) ? $settings['videocta_bg']['id'] : '';

		// Image
		$image_url = wp_get_attachment_url($bg_image);
		$image_alt = get_post_meta($bg_image, '_wp_attachment_image_alt', true);

		if ($videocta_style == 'style-one') {
			$wrapper_class = 'wpo-video-section';
			$wrapper_container = 'container-fluid';
		} else {
			$wrapper_class = 'wpo-video-section-s2';
			$wrapper_container = 'container';
		}

		// Turn output buffer on
		ob_start(); ?>
		<div class="lovelove-video-cta <?php echo esc_attr($wrapper_class); ?>">
			<div class="<?php echo esc_attr($wrapper_container); ?>">
				<div class="video-wrap">
					<?php
					if ($image_url) {
						echo '<img src="' . esc_url($image_url) . '" alt="' . esc_attr($image_alt) . '">';
					}
					if ($video_link) { ?>
						<a href="<?php echo esc_url($video_link); ?>" class="video-btn" data-type="iframe">
							<i class="fi flaticon-play"></i>
						</a>
					<?php }
					?>
				</div>
			</div>
		</div>
<?php // Return outbut buffer
		echo ob_get_clean();
	}
	/**
	 * Render CTA widget output in the editor.
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 */

	//protected function _content_template(){}

}
Plugin::instance()->widgets_manager->register(new Lovelove_Video_CTA());
