<?php
/*
 * All Metabox related options for Lovelove theme.
 * Author & Copyright:wpoceans
 * URL: http://themeforest.net/user/wpoceans
 */

function lovelove_metabox_options( $options ) {

 $cf7 = get_posts( 'post_type="wpcf7_contact_form"&numberposts=-1' );
    $contact_forms = array();
    if ( $cf7 ) {
      foreach ( $cf7 as $cform ) {
        $contact_forms[ $cform->ID ] = $cform->post_title;
      }
    } else {
      $contact_forms[ esc_html__( 'No contact forms found', 'lovelove' ) ] = 0;
    }
  $options      = array();

  // -----------------------------------------
  // Post Metabox Options                    -
  // -----------------------------------------
  $options[]    = array(
    'id'        => 'post_type_metabox',
    'title'     => esc_html__('Post Options', 'lovelove'),
    'post_type' => 'post',
    'context'   => 'normal',
    'priority'  => 'default',
    'sections'  => array(

      // All Post Formats
      array(
        'name'   => 'section_post_formats',
        'fields' => array(

          // Standard, Image
          array(
            'title' => 'Standard Image',
            'type'  => 'subheading',
            'content' => esc_html__('There is no Extra Option for this Post Format!', 'lovelove'),
            'wrap_class' => 'lovelove-minimal-heading hide-title',
          ),
          // Standard, Image

          // Gallery
          array(
            'type'    => 'notice',
            'title'   => 'Gallery Format',
            'wrap_class' => 'hide-title',
            'class'   => 'info cs-lovelove-heading',
            'content' => esc_html__('Gallery Format', 'lovelove')
          ),
          array(
            'id'          => 'gallery_post_format',
            'type'        => 'gallery',
            'title'       => esc_html__('Add Gallery', 'lovelove'),
            'add_title'   => esc_html__('Add Image(s)', 'lovelove'),
            'edit_title'  => esc_html__('Edit Image(s)', 'lovelove'),
            'clear_title' => esc_html__('Clear Image(s)', 'lovelove'),
          ),
          array(
            'type'    => 'text',
            'title'   => esc_html__('Add Video URL', 'lovelove' ),
            'id'   => 'video_post_format',
            'desc' => esc_html__('Add youtube or vimeo video link', 'lovelove' ),
            'wrap_class' => 'video_post_format',
          ),
          array(
            'type'    => 'icon',
            'title'   => esc_html__('Add Quote Icon', 'lovelove' ),
            'id'   => 'quote_post_format',
            'desc' => esc_html__('Add Quote Icon here', 'lovelove' ),
            'wrap_class' => 'quote_post_format',
          ),
          // Gallery

        ),
      ),

    ),
  );

  // -----------------------------------------
  // Page Metabox Options                    -
  // -----------------------------------------
  $options[]    = array(
    'id'        => 'page_type_metabox',
    'title'     => esc_html__('Page Custom Options', 'lovelove'),
    'post_type' => array('post', 'page'),
    'context'   => 'normal',
    'priority'  => 'default',
    'sections'  => array(

      // Title Section
      array(
        'name'  => 'page_topbar_section',
        'title' => esc_html__('Top Bar', 'lovelove'),
        'icon'  => 'fa fa-minus',

        // Fields Start
        'fields' => array(

          array(
            'id'           => 'topbar_options',
            'type'         => 'image_select',
            'title'        => esc_html__('Topbar', 'lovelove'),
            'options'      => array(
              'default'     => LOVELOVE_CS_IMAGES .'/topbar-default.png',
              'custom'      => LOVELOVE_CS_IMAGES .'/topbar-custom.png',
              'hide_topbar' => LOVELOVE_CS_IMAGES .'/topbar-hide.png',
            ),
            'attributes' => array(
              'data-depend-id' => 'hide_topbar_select',
            ),
            'radio'     => true,
            'default'   => 'default',
          ),
          array(
            'id'          => 'top_left',
            'type'        => 'textarea',
            'title'       => esc_html__('Top Left', 'lovelove'),
            'dependency'  => array('hide_topbar_select', '==', 'custom'),
            'shortcode'       => true,
          ),
          array(
            'id'          => 'top_right',
            'type'        => 'textarea',
            'title'       => esc_html__('Top Right', 'lovelove'),
            'dependency'  => array('hide_topbar_select', '==', 'custom'),
            'shortcode'       => true,
          ),
          array(
            'id'    => 'topbar_bg',
            'type'  => 'color_picker',
            'title' => esc_html__('Topbar Background Color', 'lovelove'),
            'dependency'  => array('hide_topbar_select', '==', 'custom'),
          ),
          array(
            'id'    => 'topbar_border',
            'type'  => 'color_picker',
            'title' => esc_html__('Topbar Border Color', 'lovelove'),
            'dependency'  => array('hide_topbar_select', '==', 'custom'),
          ),

        ), // End : Fields

      ), // Title Section

      // Header
      array(
        'name'  => 'header_section',
        'title' => esc_html__('Header', 'lovelove'),
        'icon'  => 'fa fa-bars',
        'fields' => array(

          array(
            'id'           => 'select_header_design',
            'type'         => 'image_select',
            'title'        => esc_html__('Select Header Design', 'lovelove'),
            'options'      => array(
              'default'     => LOVELOVE_CS_IMAGES .'/hs-0.png',
              'style_one'   => LOVELOVE_CS_IMAGES .'/hs-1.png',
              'style_two'   => LOVELOVE_CS_IMAGES .'/hs-2.png',
              'style_three'   => LOVELOVE_CS_IMAGES .'/hs-3.png',
            ),
            'attributes' => array(
              'data-depend-id' => 'header_design',
            ),
            'radio'     => true,
            'default'   => 'default',
            'info'      => esc_html__('Select your header design, following options will may differ based on your selection of header design.', 'lovelove'),
          ),
          array(
            'id'    => 'transparency_header',
            'type'  => 'switcher',
            'title' => esc_html__('Transparent Header', 'lovelove'),
            'info' => esc_html__('Use Transparent Method', 'lovelove'),
          ),
          array(
            'id'    => 'transparent_menu_color',
            'type'  => 'color_picker',
            'title' => esc_html__('Menu Color', 'lovelove'),
            'info' => esc_html__('Pick your menu color. This color will only apply for non-sticky header mode.', 'lovelove'),
            'dependency'   => array('transparency_header', '==', 'true'),
          ),
          array(
            'id'    => 'transparent_menu_hover_color',
            'type'  => 'color_picker',
            'title' => esc_html__('Menu Hover Color', 'lovelove'),
            'info' => esc_html__('Pick your menu hover color. This color will only apply for non-sticky header mode.', 'lovelove'),
            'dependency'   => array('transparency_header', '==', 'true'),
          ),
          array(
            'id'             => 'choose_menu',
            'type'           => 'select',
            'title'          => esc_html__('Choose Menu', 'lovelove'),
            'desc'          => esc_html__('Choose custom menus for this page.', 'lovelove'),
            'options'        => 'menus',
            'default_option' => esc_html__('Select your menu', 'lovelove'),
          ),

          // Enable & Disable
          array(
            'type'    => 'notice',
            'class'   => 'info cs-lovelove-heading',
            'content' => esc_html__('Enable & Disable', 'lovelove'),
            'dependency' => array('header_design', '!=', 'default'),
          ),
          array(
            'id'    => 'sticky_header',
            'type'  => 'switcher',
            'title' => esc_html__('Sticky Header', 'lovelove'),
            'info' => esc_html__('Turn On if you want your naviagtion bar on sticky.', 'lovelove'),
            'default' => true,
            'dependency' => array('header_design', '!=', 'default'),
          ),
        ),
      ),
      // Header

      // Banner & Title Area
      array(
        'name'  => 'banner_title_section',
        'title' => esc_html__('Banner & Title Area', 'lovelove'),
        'icon'  => 'fa fa-bullhorn',
        'fields' => array(

          array(
            'id'        => 'banner_type',
            'type'      => 'select',
            'title'     => esc_html__('Choose Banner Type', 'lovelove'),
            'options'   => array(
              'default-title'    => 'Default Title',
              'revolution-slider' => 'Shortcode [Rev Slider]',
              'hide-title-area'   => 'Hide Title/Banner Area',
            ),
          ),
          array(
            'id'    => 'page_revslider',
            'type'  => 'textarea',
            'title' => esc_html__('Revolution Slider or Any Shortcodes', 'lovelove'),
            'desc' => __('Enter any shortcodes that you want to show in this page title area. <br />Eg : Revolution Slider shortcode.', 'lovelove'),
            'attributes' => array(
              'placeholder' => esc_html__('Enter your shortcode...', 'lovelove'),
            ),
            'dependency'   => array('banner_type', '==', 'revolution-slider'),
          ),
          array(
            'id'    => 'page_custom_title',
            'type'  => 'text',
            'title' => esc_html__('Custom Title', 'lovelove'),
            'attributes' => array(
              'placeholder' => esc_html__('Enter your custom title...', 'lovelove'),
            ),
            'dependency'   => array('banner_type', '==', 'default-title'),
          ),
          array(
            'id'        => 'title_area_spacings',
            'type'      => 'select',
            'title'     => esc_html__('Title Area Spacings', 'lovelove'),
            'options'   => array(
              'padding-default' => esc_html__('Default Spacing', 'lovelove'),
              'padding-custom' => esc_html__('Custom Padding', 'lovelove'),
            ),
            'dependency'   => array('banner_type', '==', 'default-title'),
          ),
          array(
            'id'    => 'title_top_spacings',
            'type'  => 'text',
            'title' => esc_html__('Top Spacing', 'lovelove'),
            'attributes'  => array( 'placeholder' => '100px' ),
            'dependency'  => array('banner_type|title_area_spacings', '==|==', 'default-title|padding-custom'),
          ),
          array(
            'id'    => 'title_bottom_spacings',
            'type'  => 'text',
            'title' => esc_html__('Bottom Spacing', 'lovelove'),
            'attributes'  => array( 'placeholder' => '100px' ),
            'dependency'  => array('banner_type|title_area_spacings', '==|==', 'default-title|padding-custom'),
          ),
          array(
            'id'    => 'title_area_bg',
            'type'  => 'background',
            'title' => esc_html__('Background', 'lovelove'),
            'dependency'   => array('banner_type', '==', 'default-title'),
          ),
          array(
            'id'    => 'titlebar_bg_overlay_color',
            'type'  => 'color_picker',
            'title' => esc_html__('Overlay Color', 'lovelove'),
            'dependency'   => array('banner_type', '==', 'default-title'),
          ),
          array(
            'id'    => 'title_color',
            'type'  => 'color_picker',
            'title' => esc_html__('Title Color', 'lovelove'),
            'dependency'   => array('banner_type', '==', 'default-title'),
          ),

        ),
      ),
      // Banner & Title Area

      // Content Section
      array(
        'name'  => 'page_content_options',
        'title' => esc_html__('Content Options', 'lovelove'),
        'icon'  => 'fa fa-file',

        'fields' => array(

          array(
            'id'        => 'content_spacings',
            'type'      => 'select',
            'title'     => esc_html__('Content Spacings', 'lovelove'),
            'options'   => array(
              'padding-default' => esc_html__('Default Spacing', 'lovelove'),
              'padding-custom' => esc_html__('Custom Padding', 'lovelove'),
            ),
            'desc' => esc_html__('Content area top and bottom spacings.', 'lovelove'),
          ),
          array(
            'id'    => 'content_top_spacings',
            'type'  => 'text',
            'title' => esc_html__('Top Spacing', 'lovelove'),
            'attributes'  => array( 'placeholder' => '100px' ),
            'dependency'  => array('content_spacings', '==', 'padding-custom'),
          ),
          array(
            'id'    => 'content_bottom_spacings',
            'type'  => 'text',
            'title' => esc_html__('Bottom Spacing', 'lovelove'),
            'attributes'  => array( 'placeholder' => '100px' ),
            'dependency'  => array('content_spacings', '==', 'padding-custom'),
          ),
          array(
            'id'    => 'box_style',
            'type'  => 'switcher',
            'title' => esc_html__('Content Box Style', 'lovelove'),
            'label' => esc_html__('Yes, Please do it.', 'lovelove'),
          ),
        ), // End Fields
      ), // Content Section

      // Enable & Disable
      array(
        'name'  => 'hide_show_section',
        'title' => esc_html__('Enable & Disable', 'lovelove'),
        'icon'  => 'fa fa-toggle-on',
        'fields' => array(

          array(
            'id'    => 'hide_header',
            'type'  => 'switcher',
            'title' => esc_html__('Hide Header', 'lovelove'),
            'label' => esc_html__('Yes, Please do it.', 'lovelove'),
          ),
          array(
            'id'    => 'hide_breadcrumbs',
            'type'  => 'switcher',
            'title' => esc_html__('Hide Breadcrumbs', 'lovelove'),
            'label' => esc_html__('Yes, Please do it.', 'lovelove'),
          ),
          array(
            'id'    => 'hide_footer',
            'type'  => 'switcher',
            'title' => esc_html__('Hide Footer', 'lovelove'),
            'label' => esc_html__('Yes, Please do it.', 'lovelove'),
          ),
       
        ),
      ),
      // Enable & Disable

    ),
  );

  // -----------------------------------------
  // Page Layout
  // -----------------------------------------
  $options[]    = array(
    'id'        => 'page_layout_options',
    'title'     => esc_html__('Page Layout', 'lovelove'),
    'post_type' => 'page',
    'context'   => 'side',
    'priority'  => 'default',
    'sections'  => array(

      array(
        'name'   => 'page_layout_section',
        'fields' => array(

          array(
            'id'        => 'page_layout',
            'type'      => 'image_select',
            'options'   => array(
              'full-width'    => LOVELOVE_CS_IMAGES . '/page-1.png',
              'extra-width'   => LOVELOVE_CS_IMAGES . '/page-2.png',
              'left-sidebar'  => LOVELOVE_CS_IMAGES . '/page-3.png',
              'right-sidebar' => LOVELOVE_CS_IMAGES . '/page-4.png',
            ),
            'attributes' => array(
              'data-depend-id' => 'page_layout',
            ),
            'default'    => 'full-width',
            'radio'      => true,
            'wrap_class' => 'text-center',
          ),
          array(
            'id'            => 'page_sidebar_widget',
            'type'           => 'select',
            'title'          => esc_html__('Sidebar Widget', 'lovelove'),
            'options'        => lovelove_registered_sidebars(),
            'default_option' => esc_html__('Select Widget', 'lovelove'),
            'dependency'   => array('page_layout', 'any', 'left-sidebar,right-sidebar'),
          ),

        ),
      ),

    ),
  );

 // -----------------------------------------
  // Team
  // -----------------------------------------

  $options[]    = array(
    'id'        => 'team_options',
    'title'     => esc_html__('Team Meta', 'lovelove'),
    'post_type' => 'team',
    'context'   => 'side',
    'priority'  => 'default',
    'sections'  => array(
      array(
        'name'   => 'team_infos',
        'fields' => array(
          array(
            'title'   => esc_html__('Team Title', 'lovelove'),
            'id'      => 'team_title',
            'type'    => 'text',
            'attributes' => array(
              'placeholder' => esc_html__('Jhon Deno', 'lovelove'),
            ),
            'info'    => esc_html__('Write Team Title.', 'lovelove'),

          ),
          array(
            'title'   => esc_html__('Team Sub Title', 'lovelove'),
            'id'      => 'team_subtitle',
            'type'    => 'text',
             'attributes' => array(
              'placeholder' => esc_html__('Planner', 'lovelove'),
            ),
            'info'    => esc_html__('Write Team Sub Title.', 'lovelove'),
          ),
          // Start fields
          array(
            'id'                  => 'team_infos',
            'title'   => esc_html__('Team Info', 'lovelove'),
            'type'                => 'group',
            'fields'              => array(
              array(
                'id'              => 'info_title',
                'type'            => 'text',
                'title'           => esc_html__('Info Title', 'lovelove'),
              ),
              array(
                'id'              => 'info_desc',
                'type'            => 'text',
                'title'           => esc_html__('Info Description', 'lovelove'),
              ),
            ),
            'button_title'        => esc_html__('Add Team info', 'lovelove'),
            'accordion_title'     => esc_html__('team Info', 'lovelove'),
          ),
         array(
            'id'           => 'team_image',
            'type'         => 'image',
            'title'        => esc_html__('Team Grid Image', 'lovelove'),
            'add_title' => esc_html__('Team Image', 'lovelove'),
            'info'    => esc_html__('Attached Team Grid Image.', 'lovelove'),
          ),

        ),
      ),
    ),
  );

// -----------------------------------------
  // Project
  // -----------------------------------------
  $options[]    = array(
    'id'        => 'project_options',
    'title'     => esc_html__('Project Extra Options', 'lovelove'),
    'post_type' => 'project',
    'context'   => 'side',
    'priority'  => 'default',
    'sections'  => array(

      array(
        'name'   => 'project_option_section',
        'fields' => array(
          array(
            'id'           => 'project_title',
            'type'         => 'text',
            'title'        => esc_html__('Project title', 'lovelove'),
            'add_title' => esc_html__('Add Project title', 'lovelove'),
            'attributes' => array(
              'placeholder' => esc_html__('Project Title', 'lovelove'),
            ),
            'info'    => esc_html__('Write Project Title.', 'lovelove'),
          ), 
          array(
            'id'           => 'project_subtitle',
            'type'         => 'text',
            'title'        => esc_html__('Project subtitle', 'lovelove'),
            'add_title' => esc_html__('Add Project subtitle', 'lovelove'),
            'attributes' => array(
              'placeholder' => esc_html__('Project Sub Title', 'lovelove'),
            ),
            'info'    => esc_html__('Write Project Sub Title.', 'lovelove'),
          ),   
          array(
            'id'           => 'project_image',
            'type'         => 'image',
            'title'        => esc_html__('Project Image', 'lovelove'),
            'add_title' => esc_html__('Add Project Image', 'lovelove'),
          ),
          array(
            'id'           => 'project_image2',
            'type'         => 'image',
            'title'        => esc_html__('Project Image 2', 'lovelove'),
            'add_title' => esc_html__('Add Project Image', 'lovelove'),
          ),
           // Start fields
        ),
      ),

    ),
  );



 // -----------------------------------------
  // Service
  // -----------------------------------------

  $options[]    = array(
    'id'        => 'service_options',
    'title'     => esc_html__('Service Meta', 'lovelove'),
    'post_type' => 'service',
    'context'   => 'side',
    'priority'  => 'default',
    'sections'  => array(
      array(
        'name'   => 'service_infos',
        'fields' => array(
          array(
            'title'   => esc_html__('Service Title', 'lovelove'),
            'id'      => 'service_title',
            'type'    => 'text',
            'attributes' => array(
              'placeholder' => esc_html__('Jhon Deno', 'lovelove'),
            ),
            'info'    => esc_html__('Write Service Title.', 'lovelove'),

          ),
         array(
            'id'           => 'grid_image',
            'type'         => 'image',
            'title'        => esc_html__('Service Image', 'lovelove'),
            'add_title' => esc_html__('Service Image', 'lovelove'),
            'info'    => esc_html__('Attached Image.', 'lovelove'),
          ),
         array(
            'id'           => 'grid_image2',
            'type'         => 'image',
            'title'        => esc_html__('Service Image 2', 'lovelove'),
            'add_title' => esc_html__('Service Image', 'lovelove'),
            'info'    => esc_html__('Attached Image.', 'lovelove'),
          ),

        ),
      ),
    ),
  );


if (class_exists( 'WooCommerce' )){ 
   // -----------------------------------------
    // Product
    // -----------------------------------------
    $options[]    = array(
      'id'        => 'lovelove_woocommerce_section',
      'title'     => esc_html__('Product Custom Options', 'lovelove'),
      'post_type' => 'product',
      'context'   => 'normal',
      'priority'  => 'high',
      'sections'  => array(

        // All Post Formats
        array(
          'name'   => 'lovelove_single_title',
          'fields' => array(
            array(
              'id'          => 'lovelove_product_title',
              'type'        => 'text',
              'title'       => esc_html__('Single Title', 'lovelove'),
              'attributes' => array(
                'placeholder' => 'The Title Gose Here'
              ),
            ),
            array(
              'id'           => 'product_carousel',
              'type'         => 'image',
              'title'        => esc_html__('Carousel  Image', 'lovelove'),
              'add_title' => esc_html__('Add Carousel  Image', 'lovelove'),
            ),
            array(
              'id'           => 'product_grid',
              'type'         => 'image',
              'title'        => esc_html__('Grid  Image', 'lovelove'),
              'add_title' => esc_html__('Add Grid  Image', 'lovelove'),
            ),

          ),
        ),

      ),
    );
}
// -----------------------------------------
  // Donation Forms
  // -----------------------------------------
  $options[]    = array(
    'id'        => '_donation_form_metabox',
    'title'     => esc_html__('Donation Deadline', 'lovelove'),
    'post_type' => 'give_forms',
    'context'   => 'normal',
    'priority'  => 'high',
    'sections'  => array(

      // All Post Formats
      array(
        'name'   => 'section_deadline',
        'fields' => array(
          array(
            'id'          => 'donation_deadline',
            'type'        => 'text',
            'title'       => esc_html__('Deadline Date', 'lovelove'),
            'attributes' => array(
              'placeholder' => 'DD/MM/YYYY'
            ),
          ),
          // Gallery

        ),
      ),

    ),
  );
  
  // -----------------------------------------
  // Causes
  // -----------------------------------------
  $options[]    = array(
    'id'        => 'causes_options',
    'title'     => esc_html__('Causes Extra Options', 'lovelove'),
    'post_type' => 'give_forms',
    'context'   => 'side',
    'priority'  => 'default',
    'sections'  => array(

      array(
        'name'   => 'causes_option_section',
        'fields' => array(
         array(
            'id'           => 'causes_image',
            'type'         => 'image',
            'title'        => esc_html__('Causes Image', 'lovelove'),
            'add_title' => esc_html__('Add Causes Image', 'lovelove'),
          ),
         array(
            'id'           => 'case_form_title',
            'type'         => 'text',
            'default'    => 'Donate Now',
            'title'        => esc_html__('Form Title', 'lovelove'),
            'add_title' => esc_html__('Add Form Title here', 'lovelove'),
          ),
        ),
      ),

    ),
  );

  // -----------------------------------------
  // post options
  // -----------------------------------------
  $options[]    = array(
    'id'        => 'post_options',
    'title'     => esc_html__('Grid Image', 'lovelove'),
    'post_type' => 'post',
    'context'   => 'side',
    'priority'  => 'default',
    'sections'  => array(
      array(
        'name'   => 'post_option_section',
        'fields' => array(
          array(
            'id'           => 'widget_post_title',
            'type'         => 'text',
            'title'        => esc_html__('Widget Post Title', 'lovelove'),
            'add_title' => esc_html__('Add Widget Post Title here', 'lovelove'),
          ),
        ),
      ),

    ),
  );


  return $options;

}
add_filter( 'cs_metabox_options', 'lovelove_metabox_options' );